<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Cliente;
use App\Models\Notificacion;
use App\Models\SolicitudClienteHistorico;
use App\Models\Movimiento;
use Illuminate\Support\Facades\Auth;

class DoctoClienteController extends Controller
{
    public function ajaxVerDoctos(Request $request)
    {

        $id_cliente = intval($request->input('id_cliente'));

        $data_docto = Cliente::where(['id_cliente' => $id_cliente])
            ->select([
                'foto_dni', 'foto_dni_comprobacion', 'foto_dni_estatus',
                'foto_dni_comprobacion_estatus', 'id_cliente', 'estatus'
            ])
            ->first()->toArray();

        $tipos = ['Foto de DNI', 'Foto comprobación DNI'];
        $campos = ['foto_dni', 'foto_dni_comprobacion'];
        $estatus = ['foto_dni_estatus', 'foto_dni_comprobacion_estatus'];

        return view('ajax.doctos_clientes_ajax', compact('data_docto', 'tipos', 'campos', 'estatus'));
    }

    public function rechazarDoctos(Request $request)
    {

        $id_cliente = intval($request->input('id_cliente'));
        $texto = $request->input('texto');
        $clienteRow = Cliente::where(['id_cliente' => $id_cliente])->first();

        $update = Cliente::where(['id_cliente' => $id_cliente])->update(['estatus' => 5]);

        //ACTUALIZAMOS VALORES DE LOS DOCTOS

        if ($clienteRow->foto_dni_estatus == 'Rechazado') {
            $update = Cliente::where(['id_cliente' => $id_cliente])->update([
                'foto_dni' => NULL,
                'foto_dni_estatus' => NULL
            ]);
        }
        if ($clienteRow->foto_dni_comprobacion_estatus == 'Rechazado') {
            $update = Cliente::where(['id_cliente' => $id_cliente])->update([
                'foto_dni_comprobacion' => NULL,
                'foto_dni_comprobacion_estatus' => NULL
            ]);
        }

        //if ($update) {

        // REGISTRO DE SOLICITUD EN HISTORICO
        $solicitud = SolicitudClienteHistorico::create(
            [
                'key_user' => $clienteRow->key_user,
                'key_cliente' => $clienteRow->id_cliente,
                'estatus' => 0,
                'motivo' => $request->input('texto'),
                'key_user_admin' => Auth::id()
            ]
        );

        // REGISTRO DE MOVIMIENTO
        Movimiento::create(
            [
                'key_user' => Auth::id(),
                'seccion' => 'Gestor Clientes',
                'opcion' => 'cliente-solicitud-rechazada',
                'referencia' => $solicitud->id_solicitud
            ]
        );
        //}

        $now = date('Y-m-d H:i:s');

        //INGRESAMOS UN NUEVO REGISTRO A LAS NOTIFICACIONES DE USUARIO
        $insert = Notificacion::insert([
            'key_user' => $clienteRow->key_user,
            'texto' => $texto,
            'tipo' => 2,
            'fecha' => $now
        ]);

        if ($insert) {

            $data = array(
                'status' => 'success',
                'code' => 200,
                'statusText' => 'exito'
            );

            return response()->json($data, $data['code']);
        } else {
            $data = array(
                'status' => 'error',
                'code' => 404,
                'statusText' => 'Ha ocurrido un error. Vuelve a intentarlo y si sigue el mismo error notificalo al administrador'
            );

            return response()->json($data, $data['code']);
        }
    }



    public function aceptarDocumento(Request $request)
    {

        $id_cliente = intval($request->input('id_cliente'));
        $estatus = $request->input('estatus');
        $documento = $request->input('documento');

        $update = Cliente::where(['id_cliente' => $id_cliente])->update([$estatus => 'Aceptado']);

        $clienteRow = Cliente::where(['id_cliente' => $id_cliente])->first();
        if ($update) {

            $now = date('Y-m-d H:i:s');

            //INGRESAMOS UN NUEVO REGISTRO A LAS NOTIFICACIONES DE USUARIO
            $insert = Notificacion::insert([
                'key_user' => $clienteRow->key_user,
                'texto' => '¡Felicidades, el ' . $documento . ' ha sido aprobado!',
                'tipo' => 2,
                'fecha' => $now
            ]);

            if (
                $clienteRow->foto_dni_estatus == "Aceptado" &&
                $clienteRow->foto_dni_comprobacion_estatus == "Aceptado"
            ) {

                $update = Cliente::where(['id_cliente' => $id_cliente])->update(['estatus' => 1]);
                if ($update) {

                    $now = date('Y-m-d H:i:s');

                    //INGRESAMOS UN NUEVO REGISTRO A LAS NOTIFICACIONES DE USUARIO
                    $insert = Notificacion::insert([
                        'key_user' => $clienteRow->key_user,
                        'texto' => '¡Felicidades, tus documentos han sido aprobados!',
                        'tipo' => 2,
                        'fecha' => $now
                    ]);

                    // REGISTRO DE SOLICITUD EN HISTORICO
                    $solicitud = SolicitudClienteHistorico::create(
                        [
                            'key_user' => $clienteRow->key_user,
                            'key_cliente' => $clienteRow->id_cliente,
                            'estatus' => 1,
                            'key_user_admin' => Auth::id()
                        ]
                    );

                    // REGISTRO DE MOVIMIENTO
                    Movimiento::create(
                        [
                            'key_user' => Auth::id(),
                            'seccion' => 'Gestor Clientes',
                            'opcion' => 'cliente-solicitud-aceptada',
                            'referencia' => $solicitud->id_solicitud
                        ]
                    );
                }
            }


            return 'exito';
        } else {
            return 'Ha ocurrido un error. Vuelve a intentarlo y si sigue el mismo error notificalo al administrador';
        }
    }

    public function rechazarDocumento(Request $request)
    {

        $id_cliente = intval($request->input('id_cliente'));
        $estatus = $request->input('estatus');
        $documento = $request->input('documento');
        $clienteRow = Cliente::where(['id_cliente' => $id_cliente])->first();

        $update = Cliente::where(['id_cliente' => $id_cliente])->update([$estatus => 'Rechazado']);

        if ($update) {

            $now = date('Y-m-d H:i:s');

            //INGRESAMOS UN NUEVO REGISTRO A LAS NOTIFICACIONES DE USUARIO
            $insert = Notificacion::insert([
                'key_user' => $clienteRow->key_user,
                'texto' => '¡Lo sentimos, el ' . $documento . ' ha sido rechazado, favor de actualizarlo.!',
                'tipo' => 2,
                'fecha' => $now
            ]);

            // REGISTRO DE SOLICITUD EN HISTORICO
            /*$solicitud = SolicitudClienteHistorico::create(
                   ['key_user' => $clienteRow->key_user,
                    'key_cliente' => $clienteRow->id_cliente,
                    'estatus' => 1,
                    'key_user_admin' => session('id')
                ]);
            
            // REGISTRO DE MOVIMIENTO
            Movimiento::create(
                   ['key_user' => session('id'),
                    'seccion' => 'Gestor Clientes',
                    'opcion' => 'cliente-documento-rechazada',
                    'referencia' => $solicitud->id_solicitud
                ]);*/

            return 'exito';
        } else {
            return 'Ha ocurrido un error. Vuelve a intentarlo y si sigue el mismo error notificalo al administrador';
        }
    }

    public function volverRevisarDocumento(Request $request)
    {

        $id_cliente = intval($request->input('id_cliente'));
        $estatus = trim($request->input('estatus'));
        $documento = trim($request->input('documento'));

        $update = Cliente::where(['id_cliente' => $id_cliente])->update([$estatus => NULL]);

        if ($update) {
            return 'exito';
        } else {
            return 'Ha ocurrido un error. Vuelve a intentarlo y si sigue el mismo error notificalo al administrador' . $id_cliente . '.' . $estatus . '.' . $update;
        }
    }
}
