<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Cadian;
use App\Models\Notificacion;
use App\Models\SolicitudHistorico;
use App\Models\Movimiento;
use Illuminate\Support\Facades\Auth;

class DoctoController extends Controller
{
    public function ajaxVerDoctos(Request $request)
    {

        $id_cadian = intval($request->input('id_cadian'));
        $accion = $request->input('accion');

        $data_docto = Cadian::where(['id_cadian' => $id_cadian])
            ->select([
                'foto_dni', 'foto_dni_comprobacion', 'comprobante_factura', 'carta_no_antecedentes',
                'foto_dni_estatus', 'foto_dni_comprobacion_estatus', 'comprobante_factura_estatus', 'carta_no_antecedentes_estatus', 'estatus', 'docts_autorizados', 'fecha_autorizacion', 'id_cadian', 'key_tipo_cadian'
            ])
            ->first()->toArray();

        $tipos = ['Foto de DNI', 'Foto comprobación DNI', 'Factura (Últimos 3 meses)', 'Carta de no antecedentes'];
        $campos = ['foto_dni', 'foto_dni_comprobacion', 'comprobante_factura', 'carta_no_antecedentes'];
        $estatus = ['foto_dni_estatus', 'foto_dni_comprobacion_estatus', 'comprobante_factura_estatus', 'carta_no_antecedentes_estatus'];

        return view('ajax.doctos_cadian_ajax', [
            'data_docto' => $data_docto, 'tipos' => $tipos, 'campos' => $campos, 'estatus' => $estatus, 'accion' => $accion
        ]);
    }

    /*
    public function ajaxVerificarDoctos(Request $request){

        $id_cadian = intval($request->input('id_cadian'));

        $data_docto = Cadian::where(['id_cadian' => $id_cadian])
        ->select(['foto_dni', 'foto_dni_comprobacion', 'comprobante_factura', 'carta_no_antecedentes', 
            'foto_dni_estatus', 'foto_dni_comprobacion_estatus', 'comprobante_factura_estatus', 'carta_no_antecedentes_estatus', 'estatus', 'docts_autorizados', 'id_cadian'])
        ->first()->toArray();

        $tipos = ['Foto de DNI', 'Foto comprobación DNI', 'Factura (Últimos 3 meses)', 'Carta de no antecedentes'];
        $campos = ['foto_dni', 'foto_dni_comprobacion', 'comprobante_factura', 'carta_no_antecedentes'];
        $estatus = ['foto_dni_estatus', 'foto_dni_comprobacion_estatus', 'comprobante_factura_estatus', 'carta_no_antecedentes_estatus'];

        return view('ajax.doctos_cadian_ajax', compact('data_docto', 'tipos', 'campos', 'estatus'));


    }*/


    public function aceptarDoctos(Request $request)
    {

        $id_cadian = intval($request->input('id_cadian'));
        $cadianRow = Cadian::where(['id_cadian' => $id_cadian])->first();

        $update = Cadian::where(['id_cadian' => $id_cadian])->update(['estatus' => 1, 'docts_autorizados' => 1]);

        if ($update) {

            $now = date('Y-m-d H:i:s');

            //INGRESAMOS UN NUEVO REGISTRO A LAS NOTIFICACIONES DE USUARIO
            $insert = Notificacion::insert([
                'key_user' => $cadianRow->key_user,
                'texto' => '¡Felicidades, tus documentos han sido aprobados!',
                'tipo' => 2,
                'id_referencia' => 2,
                'fecha' => $now
            ]);

            // REGISTRO DE SOLICITUD EN HISTORICO
            $solicitud = SolicitudHistorico::create(
                [
                    'key_user' => $cadianRow->key_user,
                    'key_cadian' => $cadianRow->id_cadian,
                    'estatus' => 1,
                    'key_user_admin' =>  Auth::id()
                ]
            );

            // REGISTRO DE MOVIMIENTO
            Movimiento::create(
                [
                    'key_user' => Auth::id(),
                    'seccion' => 'Gestor Cadians',
                    'opcion' => 'cadian-solicitud-aceptada',
                    'referencia' => $solicitud->id_solicitud
                ]
            );

            return 'exito';
        } else {
            return 'Ha ocurrido un error. Vuelve a intentarlo y si sigue el mismo error notificalo al administrador';
        }
    }

    public function rechazarDoctos(Request $request)
    {

        $id_cadian = intval($request->input('id_cadian'));
        $texto = $request->input('texto');
        $cadianRow = Cadian::where(['id_cadian' => $id_cadian])->first();

        //ACTUALIZAMOS VALORES DE LOS DOCTOS

        if ($cadianRow->foto_dni_estatus == 'Rechazado') {
            $update = Cadian::where(['id_cadian' => $id_cadian])->update([
                'foto_dni' => NULL,
                'foto_dni_estatus' => NULL
            ]);
        }
        if ($cadianRow->foto_dni_comprobacion_estatus == 'Rechazado') {
            $update = Cadian::where(['id_cadian' => $id_cadian])->update([
                'foto_dni_comprobacion' => NULL,
                'foto_dni_comprobacion_estatus' => NULL
            ]);
        }

        $update = Cadian::where(['id_cadian' => $id_cadian])->update([
            'docts_autorizados' => 0,
            'fecha_autorizacion' => NULL
        ]);


        //if ($update) {

        // REGISTRO DE SOLICITUD EN HISTORICO
        $solicitud = SolicitudHistorico::create(
            [
                'key_user' => $cadianRow->key_user,
                'key_cadian' => $cadianRow->id_cadian,
                'estatus' => 0,
                'motivo' => $request->input('texto'),
                'key_user_admin' =>  Auth::id()
            ]
        );

        // REGISTRO DE MOVIMIENTO
        Movimiento::create(
            [
                'key_user' => Auth::id(),
                'seccion' => 'Gestor Cadians',
                'opcion' => 'cadian-solicitud-rechazada',
                'referencia' => $solicitud->id_solicitud
            ]
        );
        //}

        $now = date('Y-m-d H:i:s');

        //INGRESAMOS UN NUEVO REGISTRO A LAS NOTIFICACIONES DE USUARIO
        $insert = Notificacion::insert([
            'key_user' => $cadianRow->key_user,
            'texto' => $texto,
            'tipo' => 2,
            'id_referencia' => 2,
            'fecha' => $now
        ]);

        if ($insert) {

            $data = array(
                'status' => 'success',
                'code' => 200,
                'statusText' => 'exito'
            );

            return response()->json($data, $data['code']);
        } else {
            $data = array(
                'status' => 'error',
                'code' => 404,
                'statusText' => 'Ha ocurrido un error. Vuelve a intentarlo y si sigue el mismo error notificalo al administrador'
            );

            return response()->json($data, $data['code']);
        }
    }


    public function aceptarDocumento(Request $request)
    {

        $id_cadian = intval($request->input('id_cadian'));
        $estatus = $request->input('estatus');
        $documento = $request->input('documento');

        $update = Cadian::where(['id_cadian' => $id_cadian])->update([$estatus => 'Aceptado']);

        $cadianRow = Cadian::where(['id_cadian' => $id_cadian])->first();
        if ($update) {

            $now = date('Y-m-d H:i:s');

            //INGRESAMOS UN NUEVO REGISTRO A LAS NOTIFICACIONES DE USUARIO
            $insert = Notificacion::insert([
                'key_user' => $cadianRow->key_user,
                'texto' => '¡Felicidades, el ' . $documento . ' ha sido aprobado!',
                'tipo' => 2,
                'id_referencia' => 2,
                'fecha' => $now
            ]);

            /*if( $cadianRow->foto_dni_estatus == "Aceptado" && 
                $cadianRow->foto_dni_comprobacion_estatus == "Aceptado" && 
                $cadianRow->comprobante_factura_estatus == "Aceptado" && 
                $cadianRow->carta_no_antecedentes_estatus == "Aceptado"){

            if( $cadianRow->foto_dni_estatus == "Aceptado" && 
                $cadianRow->foto_dni_comprobacion_estatus == "Aceptado"){


                    $update = Cadian::where(['id_cadian' => $id_cadian])->update([
                                                'docts_autorizados' => 1, 
                                                'estatus' => 1 ]);
                    if ($update) {

                        $now = date('Y-m-d H:i:s');

                        //INGRESAMOS UN NUEVO REGISTRO A LAS NOTIFICACIONES DE USUARIO
                        $insert = Notificacion::insert([
                            'key_user' => $cadianRow->key_user,
                            'texto' => '¡Felicidades, tus documentos han sido aprobados!',
                            'tipo' => 2,
                            'id_referencia' => 2,
                            'fecha' => $now
                        ]);
                        
                        // REGISTRO DE SOLICITUD EN HISTORICO
                        $solicitud = SolicitudHistorico::create(
                               ['key_user' => $cadianRow->key_user,
                                'key_cadian' => $cadianRow->id_cadian,
                                'estatus' => 1,
                                'key_user_admin' => session('id')
                            ]);
                        
                        // REGISTRO DE MOVIMIENTO
                        Movimiento::create(
                               ['key_user' => session('id'),
                                'seccion' => 'Gestor Cadians',
                                'opcion' => 'cadian-solicitud-aceptada',
                                'referencia' => $solicitud->id_solicitud
                            ]);
                    }
            }*/


            return 'exito';
        } else {
            return 'Ha ocurrido un error. Vuelve a intentarlo y si sigue el mismo error notificalo al administrador';
        }
    }

    public function rechazarDocumento(Request $request)
    {

        $id_cadian = intval($request->input('id_cadian'));
        $estatus = $request->input('estatus');
        $documento = $request->input('documento');
        $cadianRow = Cadian::where(['id_cadian' => $id_cadian])->first();

        $update = Cadian::where(['id_cadian' => $id_cadian])->update([$estatus => 'Rechazado']);

        if ($update) {

            $now = date('Y-m-d H:i:s');

            //INGRESAMOS UN NUEVO REGISTRO A LAS NOTIFICACIONES DE USUARIO
            $insert = Notificacion::insert([
                'key_user' => $cadianRow->key_user,
                'texto' => '¡Lo sentimos, el ' . $documento . ' ha sido rechazado, favor de actualizarlo.!',
                'tipo' => 2,
                'id_referencia' => 2,
                'fecha' => $now
            ]);

            // REGISTRO DE SOLICITUD EN HISTORICO
            /*$solicitud = SolicitudHistorico::create(
                   ['key_user' => $cadianRow->key_user,
                    'key_cadian' => $cadianRow->id_cadian,
                    'estatus' => 1,
                    'key_user_admin' => session('id')
                ]);*/

            // REGISTRO DE MOVIMIENTO
            /*Movimiento::create(
                   ['key_user' => session('id'),
                    'seccion' => 'Gestor Cadians',
                    'opcion' => 'cadian-documento-aceptada',
                    'referencia' => $solicitud->id_solicitud
                ]);*/

            return 'exito';
        } else {
            return 'Ha ocurrido un error. Vuelve a intentarlo y si sigue el mismo error notificalo al administrador';
        }
    }

    public function volverRevisarDocumento(Request $request)
    {

        $id_cadian = intval($request->input('id_cadian'));
        $estatus = trim($request->input('estatus'));
        $documento = trim($request->input('documento'));

        $update = Cadian::where(['id_cadian' => $id_cadian])->update([$estatus => NULL]);

        if ($update) {
            return 'exito';
        } else {
            return 'Ha ocurrido un error. Vuelve a intentarlo y si sigue el mismo error notificalo al administrador' . $id_cadian . '.' . $estatus . '.' . $update;
        }
    }



    public function aceptarVerificacion(Request $request)
    {

        $id_cadian = intval($request->input('id_cadian'));

        $cadianRow = Cadian::where(['id_cadian' => $id_cadian])->first();

        $now = date('Y-m-d H:i:s');
        $update = Cadian::where(['id_cadian' => $id_cadian])->update(['estatus' => 1, 'fecha_autorizacion' => $now]);

        if ($update) {

            //INGRESAMOS UN NUEVO REGISTRO A LAS NOTIFICACIONES DE USUARIO
            $insert = Notificacion::insert([
                'key_user' => $cadianRow->key_user,
                'texto' => '¡Felicidades, tus documentos han sido verificados!',
                'tipo' => 2,
                'id_referencia' => 2,
                'fecha' => $now
            ]);

            // REGISTRO DE SOLICITUD EN HISTORICO
            $solicitud = SolicitudHistorico::create(
                [
                    'key_user' => $cadianRow->key_user,
                    'key_cadian' => $cadianRow->id_cadian,
                    'estatus' => 1,
                    'key_user_admin' =>  Auth::id()
                ]
            );

            // REGISTRO DE MOVIMIENTO
            Movimiento::create(
                [
                    'key_user' => Auth::id(),
                    'seccion' => 'Gestor Cadians',
                    'opcion' => 'cadian-verificacion-aceptada',
                    'referencia' => $solicitud->id_solicitud
                ]
            );

            return 'exito';
        } else {
            return 'Ha ocurrido un error. Vuelve a intentarlo y si sigue el mismo error notificalo al administrador';
        }
    }

    public function rechazarVerificacion(Request $request)
    {

        $id_cadian = intval($request->input('id_cadian'));
        $texto = $request->input('texto');

        $cadianRow = Cadian::where(['id_cadian' => $id_cadian])->first();

        //ACTUALIZAMOS VALORES DE LOS DOCTOS

        if ($cadianRow->comprobante_factura_estatus == 'Rechazado') {
            $update = Cadian::where(['id_cadian' => $id_cadian])->update([
                'comprobante_factura' => NULL,
                'comprobante_factura_estatus' => NULL,
                'fecha_autorizacion' => NULL
            ]);
        }
        if ($cadianRow->carta_no_antecedentes_estatus == 'Rechazado') {
            $update = Cadian::where(['id_cadian' => $id_cadian])->update([
                'carta_no_antecedentes' => NULL,
                'carta_no_antecedentes_estatus' => NULL,
                'fecha_autorizacion' => NULL
            ]);
        }

        //if ($update) {

        // REGISTRO DE SOLICITUD EN HISTORICO
        $solicitud = SolicitudHistorico::create(
            [
                'key_user' => $cadianRow->key_user,
                'key_cadian' => $cadianRow->id_cadian,
                'estatus' => 0,
                'motivo' => $texto,
                'key_user_admin' => Auth::id()
            ]
        );

        // REGISTRO DE MOVIMIENTO
        Movimiento::create(
            [
                'key_user' => Auth::id(),
                'seccion' => 'Gestor Cadians',
                'opcion' => 'cadian-verificacion-rechazada',
                'referencia' => $solicitud->id_solicitud
            ]
        );
        //}

        $now = date('Y-m-d H:i:s');

        //INGRESAMOS UN NUEVO REGISTRO A LAS NOTIFICACIONES DE USUARIO
        $insert = Notificacion::insert([
            'key_user' => $cadianRow->key_user,
            'texto' => $texto,
            'tipo' => 2,
            'id_referencia' => 2,
            'fecha' => $now
        ]);

        if ($insert) {

            $data = array(
                'status' => 'success',
                'code' => 200,
                'statusText' => 'exito'
            );

            return response()->json($data, $data['code']);
        } else {
            $data = array(
                'status' => 'error',
                'code' => 404,
                'statusText' => 'Ha ocurrido un error. Vuelve a intentarlo y si sigue el mismo error notificalo al administrador'
            );

            return response()->json($data, $data['code']);
        }
    }
}
