<?php

namespace App\Http\Controllers;

use App\Models\Cadian;
use App\Models\Movimiento;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class EstatusCadianController extends Controller
{
    public function index()
    {
        /* $data = Cadian::where(['estatus' => 2])
            ->latest('id_cadian')
            ->paginate(5); */

        $limit = 5;
        $offset = 0;
        $data_query = Cadian::where(['estatus' => 2])
            ->latest('id_cadian')
            ->skip($offset)->take($limit)->get();
        $data_query_count = Cadian::where(['estatus' => 2])
            ->latest('id_cadian')->get();

        $total_pages = ceil($data_query_count->count() / $limit);


        return view('estatus-cadians', ['data' => $data_query, 'number_page' => 1, 'count_queries' => $total_pages]);
    }

    public function cambiar(Request $request)
    {

        $id_cadian = $request->input('id_cadian');
        $estatus_input = $request->input('estatus');
        $cadian = Cadian::find($id_cadian);

        $flag = false;

        if (is_object($cadian)) {

            $opcion = "";

            if ($cadian->estatus == 2 && ($estatus_input == 1 || $estatus_input == 4)) {
                $flag = true;

                if ($estatus_input == 1) $opcion = 'cadian-autorizar';
                else $opcion = 'cadian-rechazar';
            } else if ($cadian->estatus == 1 && ($estatus_input == 3 || $estatus_input == 4)) {
                $flag = true;

                if ($estatus_input == 3) $opcion = 'cadian-suspender';
                else $opcion = 'cadian-cancelar';
            } else if ($cadian->estatus == 3 && $estatus_input == 1) {
                $flag = true;
                $opcion = 'cadian-autorizar';
            } else {
                return 'Datos de entrada inválidos';
            }

            if ($flag) {

                $update = Cadian::Where(['id_cadian' => $id_cadian])
                    ->update([
                        'estatus' => $estatus_input
                    ]);


                if ($estatus_input == 1) {
                    $update2 = Cadian::where('id_cadian', $id_cadian)->update([
                        'fecha_autorizacion' => date('Y-m-d H:i:s')
                    ]);
                } else if ($estatus_input == 3 || $estatus_input == 4) {
                    $update2 = Cadian::where('id_cadian', $id_cadian)->update([
                        'fecha_autorizacion' => NULL
                    ]);
                }

                // REGISTRO DE MOVIMIENTO
                Movimiento::create(
                    [
                        'key_user' => Auth::id(),
                        'seccion' => 'Gestor Cadians',
                        'opcion' => $opcion,
                        'referencia' => $id_cadian
                    ]
                );
            }

            return 'success';
        }
    }

    public function showEstatus($id_estatus)
    {
        $estatus_html = '';

        switch ($id_estatus) {
            case 1:
                $estatus_html = '
                <span class="badge badge-dot mr-4">
                  <i class="bg-success"></i> Activo
                </span>';
                break;
            case 2:
                $estatus_html = '
                <span class="badge badge-dot mr-4">
                  <i class="bg-info"></i> Revisión
                </span>';
                break;
            case 3:
                $estatus_html = '
                <span class="badge badge-dot mr-4">
                  <i class="bg-warning"></i> Suspendido
                </span>';
                break;
            case 4:
                $estatus_html = '
                <span class="badge badge-dot mr-4">
                  <i class="bg-danger"></i> Cancelado
                </span>';
                break;
            case 5:
                $estatus_html = '
                <span class="badge badge-dot mr-4">
                  <i class="bg-danger"></i> Pre-registrado
                </span>';
                break;
        }

        return $estatus_html;
    }

    public function showVerificacion($verificacion)
    {
        $verificacion_html = '';

        switch ($verificacion) {
            case 0:
                $verificacion_html = '
                <span class="badge badge-dot mr-4">
                  <i class="bg-danger"></i> No pagada
                </span>';
                break;
            case 1:
                $verificacion_html = '
                <span class="badge badge-dot mr-4">
                  <i class="bg-success"></i> Pagada
                </span>';
                break;
        }

        return $verificacion_html;
    }

    public function updateEstatus(Request $request)
    {
        //VALIDAR DATOS DE ENTRADA
        $validate = \Validator::make($request->all(), [
            'id_usuario' => 'numeric',
            'estatus' => 'in:1,2,3,4'
        ]);

        if ($validate->fails()) {
            return redirect()->back()->with('error', 'Datos de entrada inválidos.');
        }

        $id_usuario = $request->input('id_usuario');
        $estatus = $request->input('estatus');

        //ACTUALIZAMOS EN LA BD EL ESTATUS DEL USUARIO 
        $update = Cadian::where('id_cadian', $id_usuario)->update([
            'estatus' => $estatus
        ]);

        $opcion = "";

        if ($estatus == 1) {
            $update2 = Cadian::where('id_cadian', $id_usuario)->update([
                'fecha_autorizacion' => date('Y-m-d H:i:s')
            ]);

            $opcion = 'cadian-autorizar';
        } else if ($estatus == 3 || $estatus == 4) {
            $update2 = Cadian::where('id_cadian', $id_usuario)->update([
                'fecha_autorizacion' => NULL
            ]);
            if ($estatus == 3) $opcion = 'cadian-suspender';
            else $opcion = 'cadian-cancelar';
        }

        // REGISTRO DE MOVIMIENTO
        Movimiento::create(
            [
                'key_user' => Auth::id(),
                'seccion' => 'Gestor',
                'opcion' => $opcion,
                'referencia' => $id_usuario
            ]
        );
    }

    public function ajaxPaginacion(Request $request)
    {
        $busqueda = $request->input('busqueda');
        $estatus_selected = $request->input('estatus');

        if ($request->ajax()) {

            $data = Cadian::where('estatus', $estatus_selected)->where(function ($query) use ($busqueda) {
                $query->where('nombre', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('apellidos', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('correo', 'LIKE', '%' . $busqueda . '%');
            })
                ->latest('id_cadian')
                ->paginate(5);

            return view('ajax.estatus-cadian_data', ['data' => $data])->render();
        }
    }

    public function ajaxBuscar(Request $request)
    {
        $busqueda = $request->input('busqueda');
        $estatus_selected = $request->input('estatus');
        $page = $request->input('page');
        if ($request->ajax()) {
            $limit = 5;
            $offset = ($request->page - 1) * $limit;
            $data = Cadian::where('estatus', $estatus_selected)->where(function ($query) use ($busqueda) {
                $query->where('nombre', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('apellidos', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('correo', 'LIKE', '%' . $busqueda . '%');
            })->latest('id_cadian')
                ->skip($offset)->take($limit)->get();

            $data_query_count = Cadian::where('estatus', $estatus_selected)->where(function ($query) use ($busqueda) {
                $query->where('nombre', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('apellidos', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('correo', 'LIKE', '%' . $busqueda . '%');
            })->latest('id_cadian')->get();

            $total_pages = ceil($data_query_count->count() / $limit);

            return view('ajax.estatus-cadian_data', ['data' => $data, 'number_page' => $page, 'count_queries' => $total_pages])->render();
        }
    }
}
