<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Cliente;
use App\Models\Movimiento;
use Illuminate\Support\Facades\Auth;

class EstatusClienteController extends Controller
{
    public function index()
    {



        $limit = 5;
        $offset = 0;
        $data_query = Cliente::where(['estatus' => 1])
            ->latest('id_cliente')
            ->skip($offset)->take($limit)->get();
        $data_query_count = Cliente::where(['estatus' => 1])
            ->latest('id_cliente')->get();

        $total_pages = ceil($data_query_count->count() / $limit);


        /* $data = Cliente::where(['estatus' => 1])
            ->latest('id_cliente')
            ->paginate(5); */
        return view('estatus-clientes', ['data' => $data_query, 'number_page' => 1, 'count_queries' => $total_pages]);
    }

    public function cambiar(Request $request)
    {

        $id_cliente = $request->input('id_cliente');
        $estatus_input = $request->input('estatus');
        $cliente = Cliente::find($id_cliente);

        $flag = false;

        if (is_object($cliente)) {

            $opcion = "";

            if ($cliente->estatus == 2 && ($estatus_input == 1 || $estatus_input == 4)) {
                $flag = true;
                if ($estatus_input == 1) $opcion = "cliente-autorizar";
                else $opcion = "cliente-rechazar";
            } else if ($cliente->estatus == 1 && ($estatus_input == 3 || $estatus_input == 4)) {
                $flag = true;
                if ($estatus_input == 3) $opcion = "cliente-suspender";
                else $opcion = "cliente-cancelar";
            } else {
                return $estatus_input . 'Datos de entrada inválidos' . $cliente->estatus;
            }

            if ($flag) {
                $update = Cliente::Where(['id_cliente' => $id_cliente])
                    ->update([
                        'estatus' => $estatus_input
                    ]);

                // REGISTRO DE MOVIMIENTO
                Movimiento::create(
                    [
                        'key_user' => Auth::id(),
                        'seccion' => 'Gestor Clientes',
                        'opcion' => $opcion,
                        'referencia' => $id_cliente
                    ]
                );
            }

            return 'success';
        }
    }

    public function showEstatus($id_estatus)
    {
        $estatus_html = '';

        switch ($id_estatus) {
            case 1:
                $estatus_html = '
                <span class="badge badge-dot mr-4">
                  <i class="bg-success"></i> Activo
                </span>';
                break;
            case 2:
                $estatus_html = '
                <span class="badge badge-dot mr-4">
                  <i class="bg-info"></i> Revisión
                </span>';
                break;
            case 3:
                $estatus_html = '
                <span class="badge badge-dot mr-4">
                  <i class="bg-warning"></i> Suspendido
                </span>';
                break;
            case 4:
                $estatus_html = '
                <span class="badge badge-dot mr-4">
                  <i class="bg-danger"></i> Cancelado
                </span>';
                break;
            case 5:
                $estatus_html = '
                <span class="badge badge-dot mr-4">
                  <i class="bg-danger"></i> Pre-registrado
                </span>';
                break;
        }

        return $estatus_html;
    }

    public function updateEstatus(Request $request)
    {
        //VALIDAR DATOS DE ENTRADA
        $validate = \Validator::make($request->all(), [
            'id_usuario' => 'numeric',
            'estatus' => 'in:1,2,3,4'
        ]);

        if ($validate->fails()) {
            return redirect()->back()->with('error', 'Datos de entrada inválidos.');
        }

        $id_usuario = $request->input('id_usuario');
        $estatus = $request->input('estatus');

        //ACTUALIZAMOS EN LA BD EL ESTATUS DEL USUARIO 
        $update = Cliente::where('id_cliente', $id_usuario)->update([
            'estatus' => $estatus
        ]);
    }

    public function ajaxPaginacion(Request $request)
    {
        $busqueda = trim($request->input('busqueda'));
        $estatus_selected = $request->input('estatus');

        if ($request->ajax()) {

            $data = Cliente::where('estatus', $estatus_selected)->where(function ($query) use ($busqueda) {
                $query->where('nombre', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('apellidos', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('correo', 'LIKE', '%' . $busqueda . '%');
            })->paginate(5);

            return view('ajax.estatus-cliente_data', ['data' => $data])->render();
        }
    }

    public function ajaxBuscar(Request $request)
    {
        $busqueda = trim($request->input('busqueda'));
        $estatus_selected = $request->input('estatus');
        $page = $request->input('page');
        if ($request->ajax()) {
            $limit = 5;
            $offset = ($request->page - 1) * $limit;
            $data_query = Cliente::where('estatus', $estatus_selected)->where(function ($query) use ($busqueda) {
                $query->where('nombre', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('apellidos', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('correo', 'LIKE', '%' . $busqueda . '%');
            })->skip($offset)->take($limit)->get();
            $data_query_count = Cliente::where('estatus', $estatus_selected)->where(function ($query) use ($busqueda) {
                $query->where('nombre', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('apellidos', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('correo', 'LIKE', '%' . $busqueda . '%');
            })->get();

            $total_pages = ceil($data_query_count->count() / $limit);

            /* 
            $data = Cliente::where('estatus', $estatus_selected)->where(function ($query) use ($busqueda) {
                $query->where('nombre', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('apellidos', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('correo', 'LIKE', '%' . $busqueda . '%');
            })->paginate(5);
                */
            return view('ajax.estatus-cliente_data', ['data' => $data_query, 'number_page' => $page, 'count_queries' => $total_pages])->render();
        }
    }
}
