<?php

namespace App\Http\Controllers;

use Illuminate\Validation\Rule;
use Illuminate\Http\Request;
use App\Models\CategoriaBlog;
use App\Models\SubCategoriaBlog;
use App\Models\Blog;
use App\Models\Movimiento;
use Illuminate\Support\Facades\Auth;

class GestorBlogController extends Controller
{

    public function index()
    {

        // CATEGORIAS PARA FILTRO
        $categorias = CategoriaBlog::all();

        // SUBCATEGORIAS PARA FILTRO
        $subcategorias = SubCategoriaBlog::where('key_categoria', '=', 1)->get();

        // LISTADO INICIAL DEL BLOG
        $blog = Blog::select('ci_blog.*', 'ci_subcategorias_blogs.nombre as subcategoria', 'ci_categorias_blogs.nombre as categoria')
            ->join('ci_subcategorias_blogs', 'ci_subcategorias_blogs.id', '=', 'ci_blog.key_subcategoria')
            ->join('ci_categorias_blogs', 'ci_categorias_blogs.id', '=', 'ci_subcategorias_blogs.key_categoria')
            ->where('eliminada', '=', 0)
            ->paginate(5);

        return view('gestor-blog', compact('blog', 'categorias', 'subcategorias'));
    }

    public function ajaxBuscarSubcategoria($id_categoria)
    {
        // REGRESA SUBCATEGORIAS AL FILTRO
        $subcategorias = SubCategoriaBlog::where('key_categoria', $id_categoria)->get();

        return $subcategorias;
    }


    public function ajaxBuscar(Request $request)
    {
        $categoria_selected = $request->input('categoria_filtro');
        $subcategoria_selected = $request->input('subcategoria_filtro');

        /*return $categoria_selected . ' - '. $subcategoria_selected;*/

        if ($request->ajax()) {

            // LISTADO DE BLOG FILTRADOS
            $blog = Blog::select('ci_blog.*', 'ci_subcategorias_blogs.nombre as subcategoria', 'ci_categorias_blogs.nombre as categoria')
                ->join('ci_subcategorias_blogs', 'ci_subcategorias_blogs.id', '=', 'ci_blog.key_subcategoria')
                ->join('ci_categorias_blogs', 'ci_categorias_blogs.id', '=', 'ci_subcategorias_blogs.key_categoria')
                ->where('eliminada', '=', 0)
                ->where('ci_subcategorias_blogs.id', '=', $subcategoria_selected)
                ->where('ci_categorias_blogs.id', '=', $categoria_selected)
                ->paginate(5);

            return view('ajax.gestor-blog_data', compact('blog'))->render();
        }
    }


    public function nuevo()
    {

        // CATEGORIAS PARA FILTRO
        $categorias = CategoriaBlog::all();

        // SUBCATEGORIAS PARA FILTRO
        $subcategorias = SubCategoriaBlog::where('key_categoria', '=', 1)->get();

        // FORMA PARA NUEVA NOTA
        return view('gestor-blog-nuevo', compact('categorias', 'subcategorias'));
    }


    public function guardar(Request $request)
    {

        $validate = \Validator::make($request->all(), [
            //EJEMPLOS DE SANITIZACIÓN DE DATOS
            'titulo' => 'required|regex:/^[a-zA-ZÀ-ÖØ-öø-ÿ0-9¿?: ]+(\s{0,1}[a-zA-ZÀ-ÖØ-öø-ÿ0-9¿?: ])*$/',
            'url_seo' => 'required',
            'descripcion' => 'required',
            'id_subcategoria' => 'required|numeric'
        ]);

        if ($validate->fails()) {
            // Hay Error de Validación
            return $validate->errors();
        }


        // Validar imagen
        $validate_images = \Validator::make($request->all(), [
            'img_miniatura' => 'mimes:jpeg,png',
        ]);

        if ($validate_images->fails()) {
            $data = array(
                'status' => 'error',
                'code' => 404,
                'message' => 'Las imagenes no se han podido subir.',
                'errors' => $validate_images->errors()
            );

            return response()->json($data, $data['code']);
        }

        //Subir imagen

        $file = $request->file('img_miniatura');

        $image_name = time() . $file->getClientOriginalName();
        $target_path = public_path('storage/blog/');

        // Guardar blog

        if ($file->move($target_path, $image_name)) {

            $blog = Blog::create(
                [
                    'titulo' => $request['titulo'],
                    'url_seo' => $request['url_seo'],
                    'img_miniatura' => $image_name,
                    'descripcion' => $request['descripcion'],
                    'key_subcategoria' => $request['id_subcategoria']
                ]
            );



            Movimiento::create(
                [
                    'key_user' => Auth::id(),
                    'seccion' => 'Blog',
                    'opcion' => 'blog-nueva',
                    'referencia' => $blog['id']
                ]
            );
        }

        return 'success-blog-guardar';
    }



    public function editar($id_blog)
    {


        // blog
        $blog = Blog::find($id_blog);

        // SUBCATEGORIA
        $subcategoria = SubCategoriaBlog::find($blog->key_subcategoria);

        // SUBCATEGORIAS
        $subcategorias = SubCategoriaBlog::where('key_categoria', '=', $subcategoria->key_categoria)->get();

        // CATEGORIAS
        $categorias = CategoriaBlog::all();

        // FORMA PARA NUEVO blog
        return view('gestor-blog-editar', compact('blog', 'subcategorias', 'categorias', 'subcategoria'));
    }

    public function modificar(Request $request)
    {

        $validate = \Validator::make($request->all(), [
            //EJEMPLOS DE SANITIZACIÓN DE DATOS
            'titulo' => 'required|regex:/^[a-zA-ZÀ-ÖØ-öø-ÿ0-9,¿?: ]+(\s{0,1}[a-zA-ZÀ-ÖØ-öø-ÿ0-9¿?: ])*$/',
            'url_seo' => 'required',
            'descripcion' => 'required',
            'publicada' => 'required|numeric',
            'id_subcategoria' => 'required|numeric',
            'id' => 'required|numeric'
        ]);

        if ($validate->fails()) {
            // Hay Error de Validación
            return $validate->errors();
        }

        if ($request['cambiar_imagen'] == 1) {
            // SI LA IMAGEN ES NUEVA, REEMPLAZARLA

            // Validar imagen
            $validate_images = \Validator::make($request->all(), [
                'img_miniatura' => 'mimes:jpeg,png',
            ]);

            if ($validate_images->fails()) {
                $data = array(
                    'status' => 'error',
                    'code' => 404,
                    'message' => 'Las imagenes no se han podido subir.',
                    'errors' => $validate_images->errors()
                );

                return response()->json($data, $data['code']);
            }

            //Subir imagen

            $file = $request->file('img_miniatura');

            $extension = $file->getClientOriginalExtension();
            //$image_name = time().$file->getClientOriginalName();

            $image_name = time() . '.' . $extension;
            $target_path = public_path('storage/blog/');

            if ($file->move($target_path, $image_name)) {

                //ELIMINAMOS FOTO DE PERFIL ANTERIOR
                $anterior_imagen = Blog::where('id', $request['id'])->value('img_miniatura');

                if (!empty($anterior_imagen)) {
                    $image_path_anterior = public_path() . '/storage/blog/' . $anterior_imagen;
                    unlink($image_path_anterior);
                }
            }
        }

        //Guardar datos

        $blog = Blog::find($request['id']);

        $blog->titulo = $request['titulo'];
        $blog->url_seo = $request['url_seo'];
        $blog->descripcion = $request->input('descripcion');
        $blog->key_subcategoria = $request->input('id_subcategoria');
        $blog->publicada = $request->input('publicada');

        if ($request['cambiar_imagen'] == 1)
            $blog->img_miniatura = $image_name;

        $blog->save();



        Movimiento::create(
            [
                'key_user' => Auth::id(),
                'seccion' => 'Blog',
                'opcion' => 'blog-modificar',
                'referencia' => $request['id']
            ]
        );


        return 'success-blog-modificar';
    }


    // METODO PARA LISTAR BUSQUEDA PAGINADA
    public function ajaxPaginacion(Request $request)
    {
        $categoria_selected = $request->input('categoria_filtro');
        $subcategoria_selected = $request->input('subcategoria_filtro');

        /*return $categoria_selected . ' - '. $subcategoria_selected;*/

        if ($request->ajax()) {

            // LISTADO DEL BLOG FILTRADOS
            $blog = Blog::select('ci_blog.*', 'ci_subcategorias_blogs.nombre as subcategoria', 'ci_categorias_blogs.nombre as categoria')
                ->join('ci_subcategorias_blogs', 'ci_subcategorias_blogs.id', '=', 'ci_blog.key_subcategoria')
                ->join('ci_categorias_blogs', 'ci_categorias_blogs.id', '=', 'ci_subcategorias_blogs.key_categoria')
                ->where('ci_subcategorias_blogs.id', '=', $subcategoria_selected)
                ->where('ci_categorias_blogs.id', '=', $categoria_selected)
                ->paginate(5);

            return view('ajax.gestor-blog_data', compact('blog'))->render();
        }
    }



    public function ajaxVerPublicacion(Request $request)
    {

        $id_publicacion = intval($request->input('id'));

        $data_publicacion = Blog::find($id_publicacion);

        return view('ajax.gestor-blog-eliminar_data', compact('data_publicacion'));
    }

    public function eliminar(Request $request)
    {

        $validate = \Validator::make($request->all(), [
            //EJEMPLOS DE SANITIZACIÓN DE DATOS
            'id' => 'required|numeric',
        ]);

        if ($validate->fails()) {
            // Hay Error de Validación
            return $validate->errors();
        }

        $publicacion = $request['id'];

        //Guardar datos

        $blog = Blog::find($publicacion);

        $blog->eliminada = 1; // CAMBIA DE VALOR (NO BORRA)

        $blog->save();

        if (is_object($blog)) {
            // REGISTRO DE MOVIMIENTO
            Movimiento::create(
                [
                    'key_user' => Auth::id(),
                    'seccion' => 'Gestor Blog',
                    'opcion' => 'eliminar-publicacion',
                    'referencia' => $publicacion
                ]
            );
            return 'success-blog-eliminar';
        } else return 'error-blog-eliminar';
    }
}
