<?php

namespace App\Http\Controllers;


use Illuminate\Validation\Rule;
use Illuminate\Http\Request;
use App\Models\CategoriaTutorial;
use App\Models\SubCategoriaTutorial;
use App\Models\CategoriaFaqs;
use App\Models\PreguntaFaqs;
use App\Models\Movimiento;
use Illuminate\Support\Facades\Auth;

class GestorFaqsController extends Controller
{

    public function index()
    {
        $limit = 5;
        $offset = 0;
        // CATEGORIAS PARA FILTRO
        $categorias = CategoriaFaqs::all();

        // LISTADO INICIAL DE PREGUNTAS
        $preguntas = PreguntaFaqs::select('ci_faq_preguntas.*', 'ci_faq_categorias.nombre as nombre')
            ->join('ci_faq_categorias', 'ci_faq_categorias.id_categoria', '=', 'ci_faq_preguntas.key_categoria')
            ->orderBy('id_categoria', 'ASC')
            ->orderBy('id_pregunta', 'ASC')
            ->skip($offset)->take($limit)->get();
        $data_query_count = PreguntaFaqs::select('ci_faq_preguntas.*', 'ci_faq_categorias.nombre as nombre')
            ->join('ci_faq_categorias', 'ci_faq_categorias.id_categoria', '=', 'ci_faq_preguntas.key_categoria')
            ->orderBy('id_categoria', 'ASC')
            ->orderBy('id_pregunta', 'ASC')->get();
        $number_page = 1;
        $count_queries  = ceil($data_query_count->count() / $limit);

        return view('gestor-faqs', compact('categorias', 'preguntas', 'number_page', 'count_queries'));
    }


    public function nuevo()
    {

        // CATEGORIAS PARA FILTRO
        $categorias = CategoriaFaqs::all();

        $accion = 'NUEVO';

        // FORMA PARA PREGUNTA
        return view('gestor-faqs-forma', compact('accion', 'categorias'));
    }


    public function editar($id_pregunta)
    {

        // CATEGORIAS
        $categorias = CategoriaFaqs::all();

        // PREGUNTA
        $pregunta = PreguntaFaqs::find($id_pregunta);

        $accion = 'EDITAR';

        // FORMA PARA PREGUNTA
        return view('gestor-faqs-forma', compact('accion', 'categorias', 'pregunta'));
    }

    public function guardar(Request $request)
    {

        $validate = \Validator::make($request->all(), [
            //EJEMPLOS DE SANITIZACIÓN DE DATOS
            'id_categoria' => 'required|numeric',
            'url_seo' => 'required',
            'pregunta' => 'required|regex:/^[a-zA-ZÀ-ÖØ-öø-ÿ0-9¿?,.:"\ ]+(\s{0,1}[a-zA-ZÀ-ÖØ-öø-ÿ0-9¿?,.: ])*$/',
            'respuesta' => 'required|regex:/^[a-zA-ZÀ-ÖØ-öø-ÿ0-9¿?,.:"\ ]+(\s{0,1}[a-zA-ZÀ-ÖØ-öø-ÿ0-9¿?,.: ])*$/'
        ]);

        if ($validate->fails()) {
            // Hay Error de Validación
            return $validate->errors();
        }

        $pregunta = PreguntaFaqs::create(
            [
                'key_categoria' => $request['id_categoria'],
                'key_usuario' => Auth::id(),
                'url_seo' => $request['url_seo'],
                'pregunta' => trim($request['pregunta']),
                'respuesta' => trim($request['respuesta'])
            ]
        );

        if (is_object($pregunta)) {
            // REGISTRO DE MOVIMIENTO
            Movimiento::create(
                [
                    'key_user' => Auth::id(),
                    'seccion' => 'Gestor FAQS',
                    'opcion' => 'usuario-nueva-pregunta',
                    'referencia' => $pregunta['id_pregunta']
                ]
            );
            return 'success-pregunta-guardar';
        } else return 'error-pregunta-guardar';
    }


    public function modificar(Request $request)
    {

        $validate = \Validator::make($request->all(), [
            //EJEMPLOS DE SANITIZACIÓN DE DATOS
            'id_pregunta' => 'required|numeric',
            'id_categoria' => 'required|numeric',
            'url_seo' => 'required',
            'pregunta' => 'required|regex:/^[a-zA-ZÀ-ÖØ-öø-ÿ0-9¿?,.:"\ ]+(\s{0,1}[a-zA-ZÀ-ÖØ-öø-ÿ0-9¿?,.: ])*$/',
            'respuesta' => 'required|regex:/^[a-zA-ZÀ-ÖØ-öø-ÿ0-9¿?,.:"\ ]+(\s{0,1}[a-zA-ZÀ-ÖØ-öø-ÿ0-9¿?,.: ])*$/'
        ]);

        if ($validate->fails()) {
            // Hay Error de Validación
            return $validate->errors();
        }

        //Guardar datos

        $pregunta = PreguntaFaqs::find($request['id_pregunta']);

        $pregunta->key_categoria = $request['id_categoria'];
        $pregunta->url_seo = $request['url_seo'];
        $pregunta->pregunta = $request['pregunta'];
        $pregunta->respuesta = $request['respuesta'];

        $pregunta->save();

        if (is_object($pregunta)) {
            // REGISTRO DE MOVIMIENTO
            Movimiento::create(
                [
                    'key_user' => Auth::id(),
                    'seccion' => 'Gestor FAQS',
                    'opcion' => 'usuario-modificar-pregunta',
                    'referencia' => $pregunta['id_pregunta']
                ]
            );
            return 'success-pregunta-modificar';
        } else return 'error-pregunta-modificar';
    }


    public function ajaxVerPregunta(Request $request)
    {

        $id_pregunta = intval($request->input('id_pregunta'));

        $data_pregunta = PreguntaFaqs::find($request['id_pregunta']);

        return view('ajax.gestor-faqs-eliminar_data', compact('data_pregunta'));
    }

    public function eliminar(Request $request)
    {

        $validate = \Validator::make($request->all(), [
            //EJEMPLOS DE SANITIZACIÓN DE DATOS
            'id_pregunta' => 'required|numeric',
        ]);

        if ($validate->fails()) {
            // Hay Error de Validación
            return $validate->errors();
        }

        $pregunta = PreguntaFaqs::find($request['id_pregunta']);
        $pregunta->delete();


        if (is_object($pregunta)) {
            // REGISTRO DE MOVIMIENTO
            Movimiento::create(
                [
                    'key_user' => Auth::id(),
                    'seccion' => 'Gestor FAQS',
                    'opcion' => 'usuario-eliminar-pregunta',
                    'referencia' => $pregunta['id_pregunta']
                ]
            );
            return 'success-pregunta-eliminar';
        } else return 'error-pregunta-eliminar';
    }

    // BUSQUEDA O FILTRO
    public function ajaxBuscar(Request $request)
    {
        $categoria_selected = $request->input('categoria_filtro');
        $page = $request->input('page');
        if ($request->ajax()) {
            $limit = 5;
            $offset = ($page - 1) * $limit;
            // LISTADO DE PREGUNTAS FILTRADOS
            $preguntas = PreguntaFaqs::select('ci_faq_preguntas.*', 'ci_faq_categorias.nombre as nombre')
                ->join('ci_faq_categorias', 'ci_faq_categorias.id_categoria', '=', 'ci_faq_preguntas.key_categoria')
                ->where(function ($query) use ($categoria_selected) {

                    if ($categoria_selected != "") {
                        $query->where('ci_faq_preguntas.key_categoria', '=', $categoria_selected);
                    }
                })
                ->orderBy('id_categoria', 'ASC')
                ->orderBy('id_pregunta', 'ASC')
                ->skip($offset)->take($limit)->get();
            $data_query_count  =  PreguntaFaqs::select('ci_faq_preguntas.*', 'ci_faq_categorias.nombre as nombre')
                ->join('ci_faq_categorias', 'ci_faq_categorias.id_categoria', '=', 'ci_faq_preguntas.key_categoria')
                ->where(function ($query) use ($categoria_selected) {

                    if ($categoria_selected != "") {
                        $query->where('ci_faq_preguntas.key_categoria', '=', $categoria_selected);
                    }
                })
                ->orderBy('id_categoria', 'ASC')
                ->orderBy('id_pregunta', 'ASC')->get();
            $count_queries = ceil($data_query_count->count() / $limit);
            $number_page = $request->input('page');
            return view('ajax.gestor-faqs_data', compact('preguntas', 'number_page', 'count_queries'))->render();
        }
    }

    // METODO PARA LISTAR BUSQUEDA PAGINADA
    public function ajaxPaginacion(Request $request)
    {
        $categoria_selected = $request->input('categoria_filtro');

        if ($request->ajax()) {

            // LISTADO DE PREGUNTAS FILTRADOS
            $preguntas = PreguntaFaqs::select('ci_faq_preguntas.*', 'ci_faq_categorias.nombre as nombre')
                ->join('ci_faq_categorias', 'ci_faq_categorias.id_categoria', '=', 'ci_faq_preguntas.key_categoria')
                ->when(!empty($busqueda), function ($query) use ($categoria_selected) {
                    $query->where('ci_faq_preguntas.key_categoria', '=', $categoria_selected);
                })
                ->orderBy('id_categoria', 'ASC')
                ->orderBy('id_pregunta', 'ASC')
                ->paginate(5);

            return view('ajax.gestor-faqs_data', compact('preguntas'))->render();
        }
    }
}
