<?php

namespace App\Http\Controllers;


use Illuminate\Validation\Rule;
use Illuminate\Http\Request;
use App\Models\CategoriaTutorial;
use App\Models\SubCategoriaTutorial;
use App\Models\Tutorial;
use App\Models\Movimiento;
use Illuminate\Support\Facades\Auth;

class GestorTutorialController extends Controller
{
    public function index()
    {
        $limit = 5;
        $offset = 0;
        // CATEGORIAS PARA FILTRO
        $categorias = CategoriaTutorial::all();

        // SUBCATEGORIAS PARA FILTRO
        $subcategorias = SubCategoriaTutorial::where('key_categoria', '=', 1)->get();

        // LISTADO INICIAL DE TUTORIALES
        $tutoriales = Tutorial::select('ci_tutoriales.*', 'ci_subcategorias_tutoriales.nombre as subcategoria', 'ci_categorias_tutoriales.nombre as categoria')
            ->join('ci_subcategorias_tutoriales', 'ci_subcategorias_tutoriales.id', '=', 'ci_tutoriales.key_subcategoria')
            ->join('ci_categorias_tutoriales', 'ci_categorias_tutoriales.id', '=', 'ci_subcategorias_tutoriales.key_categoria')
            ->where('eliminada', '=', 0)
            ->skip($offset)->take($limit)->get();
        $data_query_count = Tutorial::select('ci_tutoriales.*', 'ci_subcategorias_tutoriales.nombre as subcategoria', 'ci_categorias_tutoriales.nombre as categoria')
            ->join('ci_subcategorias_tutoriales', 'ci_subcategorias_tutoriales.id', '=', 'ci_tutoriales.key_subcategoria')
            ->join('ci_categorias_tutoriales', 'ci_categorias_tutoriales.id', '=', 'ci_subcategorias_tutoriales.key_categoria')
            ->where('eliminada', '=', 0)->get();

        $total_pages = ceil($data_query_count->count() / $limit);

        return view('gestor-tutoriales', ['tutoriales' => $tutoriales, 'categorias' => $categorias, 'subcategorias' => $subcategorias, 'number_page' => 1, 'count_queries' => $total_pages]);
    }

    public function ajaxBuscarSubcategoria($id_categoria)
    {
        // REGRESA SUBCATEGORIAS AL FILTRO
        $subcategorias = SubCategoriaTutorial::where('key_categoria', $id_categoria)->get();

        return $subcategorias;
    }


    public function ajaxBuscar(Request $request)
    {
        $categoria_selected = $request->input('categoria_filtro');
        $subcategoria_selected = $request->input('subcategoria_filtro');
        $page = $request->input('page');
        /*return $categoria_selected . ' - '. $subcategoria_selected;*/

        if ($request->ajax()) {
            $limit = 5;
            $offset = ($request->page - 1) * $limit;
            // LISTADO DE TUTORIALES FILTRADOS
            $tutoriales = Tutorial::select('ci_tutoriales.*', 'ci_subcategorias_tutoriales.nombre as subcategoria', 'ci_categorias_tutoriales.nombre as categoria')
                ->join('ci_subcategorias_tutoriales', 'ci_subcategorias_tutoriales.id', '=', 'ci_tutoriales.key_subcategoria')
                ->join('ci_categorias_tutoriales', 'ci_categorias_tutoriales.id', '=', 'ci_subcategorias_tutoriales.key_categoria')
                ->where('eliminada', '=', 0)
                ->where('ci_subcategorias_tutoriales.id', '=', $subcategoria_selected)
                ->where('ci_categorias_tutoriales.id', '=', $categoria_selected)
                ->skip($offset)->take($limit)->get();
            $data_query_count =
                Tutorial::select('ci_tutoriales.*', 'ci_subcategorias_tutoriales.nombre as subcategoria', 'ci_categorias_tutoriales.nombre as categoria')
                ->join('ci_subcategorias_tutoriales', 'ci_subcategorias_tutoriales.id', '=', 'ci_tutoriales.key_subcategoria')
                ->join('ci_categorias_tutoriales', 'ci_categorias_tutoriales.id', '=', 'ci_subcategorias_tutoriales.key_categoria')
                ->where('eliminada', '=', 0)
                ->where('ci_subcategorias_tutoriales.id', '=', $subcategoria_selected)
                ->where('ci_categorias_tutoriales.id', '=', $categoria_selected)->get();

            $total_pages = ceil($data_query_count->count() / $limit);
            return view('ajax.gestor-tutoriales_data', ['tutoriales' => $tutoriales, 'number_page' => $page, 'count_queries' => $total_pages])->render();
        }
    }


    public function nuevo()
    {

        // CATEGORIAS PARA FILTRO
        $categorias = CategoriaTutorial::all();

        // SUBCATEGORIAS PARA FILTRO
        $subcategorias = SubCategoriaTutorial::where('key_categoria', '=', 1)->get();

        // FORMA PARA NUEVO TUTORIAL
        return view('gestor-tutoriales-nuevo', ['categorias' => $categorias, 'subcategorias' => $subcategorias]);
    }


    public function guardar(Request $request)
    {

        $validate = \Validator::make($request->all(), [
            //EJEMPLOS DE SANITIZACIÓN DE DATOS
            'titulo' => 'required|regex:/^[a-zA-ZÀ-ÖØ-öø-ÿ0-9¿?: ]+(\s{0,1}[a-zA-ZÀ-ÖØ-öø-ÿ0-9¿?: ])*$/',
            'url_seo' => 'required',
            'descripcion' => 'required',
            'id_subcategoria' => 'required|numeric'
        ]);

        if ($validate->fails()) {
            // Hay Error de Validación
            return $validate->errors();
        }


        // Validar imagen
        $validate_images = \Validator::make($request->all(), [
            'img_miniatura' => 'mimes:jpeg,png',
        ]);

        if ($validate_images->fails()) {
            $data = array(
                'status' => 'error',
                'code' => 404,
                'message' => 'Las imagenes no se han podido subir.',
                'errors' => $validate_images->errors()
            );

            return response()->json($data, $data['code']);
        }

        //Subir imagen

        $file = $request->file('img_miniatura');

        $image_name = time() . $file->getClientOriginalName();
        $target_path = public_path('storage/tutoriales/');

        // Guardar tutorial

        if ($file->move($target_path, $image_name)) {

            $tutorial = Tutorial::create(
                [
                    'titulo' => $request['titulo'],
                    'url_seo' => $request['url_seo'],
                    'img_miniatura' => $image_name,
                    'descripcion' => $request['descripcion'],
                    'key_subcategoria' => $request['id_subcategoria']
                ]
            );
        }

        return 'success-tutorial-guardar';
    }



    public function editar($id_tutorial)
    {


        // TUTORIAL
        $tutorial = Tutorial::find($id_tutorial);

        // SUBCATEGORIA
        $subcategoria = SubCategoriaTutorial::find($tutorial->key_subcategoria);

        // SUBCATEGORIAS
        $subcategorias = SubCategoriaTutorial::where('key_categoria', '=', $subcategoria->key_categoria)->get();

        // CATEGORIAS
        $categorias = CategoriaTutorial::all();

        // FORMA PARA NUEVO TUTORIAL
        return view('gestor-tutoriales-editar', ['tutorial' => $tutorial, 'categorias' => $categorias, 'subcategorias' => $subcategorias, 'subcategoria' => $subcategoria]);
    }

    public function modificar(Request $request)
    {

        $validate = \Validator::make($request->all(), [
            //EJEMPLOS DE SANITIZACIÓN DE DATOS
            'titulo' => 'required|regex:/^[a-zA-ZÀ-ÖØ-öø-ÿ0-9,¿?: ]+(\s{0,1}[a-zA-ZÀ-ÖØ-öø-ÿ0-9¿?: ])*$/',
            'url_seo' => 'required',
            'descripcion' => 'required',
            'publicada' => 'required',
            'id_subcategoria' => 'required|numeric',
            'id' => 'required|numeric'
        ]);

        if ($validate->fails()) {
            // Hay Error de Validación
            return $validate->errors();
        }

        if ($request['cambiar_imagen'] == 1) {
            // SI LA IMAGEN ES NUEVA, REEMPLAZARLA

            // Validar imagen
            $validate_images = \Validator::make($request->all(), [
                'img_miniatura' => 'mimes:jpeg,png',
            ]);

            if ($validate_images->fails()) {
                $data = array(
                    'status' => 'error',
                    'code' => 404,
                    'message' => 'Las imagenes no se han podido subir.',
                    'errors' => $validate_images->errors()
                );

                return response()->json($data, $data['code']);
            }

            //Subir imagen

            $file = $request->file('img_miniatura');

            $extension = $file->getClientOriginalExtension();
            //$image_name = time().$file->getClientOriginalName();

            $image_name = time() . '.' . $extension;
            $target_path = public_path('storage/tutoriales/');

            if ($file->move($target_path, $image_name)) {

                //ELIMINAMOS FOTO DE PERFIL ANTERIOR
                $anterior_imagen = Tutorial::where('id', $request['id'])->value('img_miniatura');

                if (!empty($anterior_imagen)) {
                    $image_path_anterior = public_path() . '/storage/tutoriales/' . $anterior_imagen;

                    if (file_exists($image_path_anterior)) {
                        unlink($image_path_anterior);
                    }
                }
            }
        }

        //Guardar datos

        $tutorial = Tutorial::find($request['id']);

        $tutorial->titulo = $request['titulo'];
        $tutorial->url_seo = $request['url_seo'];
        $tutorial->descripcion = $request->input('descripcion');
        $tutorial->publicada = $request->input('publicada');
        $tutorial->key_subcategoria = $request->input('id_subcategoria');

        if ($request['cambiar_imagen'] == 1)
            $tutorial->img_miniatura = $image_name;

        $tutorial->save();



        Movimiento::create(
            [
                'key_user' => Auth::id(),
                'seccion' => 'Tutoriales',
                'opcion' => 'tutorial-modificar',
                'referencia' => $request['id']
            ]
        );


        return 'success-tutorial-modificar';
    }


    // METODO PARA LISTAR BUSQUEDA PAGINADA
    public function ajaxPaginacion(Request $request)
    {
        $categoria_selected = $request->input('categoria_filtro');
        $subcategoria_selected = $request->input('subcategoria_filtro');

        /*return $categoria_selected . ' - '. $subcategoria_selected;*/

        if ($request->ajax()) {

            // LISTADO DE TUTORIALES FILTRADOS
            $tutoriales = Tutorial::select('ci_tutoriales.*', 'ci_subcategorias_tutoriales.nombre as subcategoria', 'ci_categorias_tutoriales.nombre as categoria')
                ->join('ci_subcategorias_tutoriales', 'ci_subcategorias_tutoriales.id', '=', 'ci_tutoriales.key_subcategoria')
                ->join('ci_categorias_tutoriales', 'ci_categorias_tutoriales.id', '=', 'ci_subcategorias_tutoriales.key_categoria')
                ->where('ci_subcategorias_tutoriales.id', '=', $subcategoria_selected)
                ->where('ci_categorias_tutoriales.id', '=', $categoria_selected)
                ->paginate(5);

            return view('ajax.gestor-tutoriales_data', ['tutoriales' => $tutoriales])->render();
        }
    }


    public function ajaxVerTutorial(Request $request)
    {

        $id_tutorial = intval($request->input('id'));

        $data_tutorial = Tutorial::find($id_tutorial);

        return view('ajax.gestor-tutorial-eliminar_data', ['data_tutorial' => $data_tutorial]);
    }

    public function eliminar(Request $request)
    {

        $validate = \Validator::make($request->all(), [
            //EJEMPLOS DE SANITIZACIÓN DE DATOS
            'id' => 'required|numeric',
        ]);

        if ($validate->fails()) {
            // Hay Error de Validación
            return $validate->errors();
        }

        $id_tutorial = $request['id'];

        //Guardar datos

        $tutorial = Tutorial::find($id_tutorial);

        $tutorial->eliminada = 1; // CAMBIA DE VALOR (NO BORRA)

        $tutorial->save();

        if (is_object($tutorial)) {
            // REGISTRO DE MOVIMIENTO
            Movimiento::create(
                [
                    'key_user' => Auth::id(),
                    'seccion' => 'Gestor Tutorial',
                    'opcion' => 'eliminar-tutorial',
                    'referencia' => $id_tutorial
                ]
            );
            return 'success-tutorial-eliminar';
        } else return 'error-tutorial-eliminar';
    }
}
