<?php

namespace App\Http\Controllers;


use Illuminate\Validation\Rule;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

use App\Models\Cliente;
use App\Models\TipoCliente;
use App\Models\Cadian;
use App\Models\TipoCadian;
use App\Models\User;
use App\Models\Genero;
use App\Models\Formacion;
use App\Models\Movimiento;
use App\Models\TokenAcceso;
use Illuminate\Support\Facades\Auth;

class GestorUsuarioController extends Controller
{
    public function index()
    {
        $limit = 5;
        $offset = 0;
        $data = User::where('role_user', '!=', 'ADMIN')
            ->skip($offset)->take($limit)->get();
        $data_query_count = User::where('role_user', '!=', 'ADMIN')->get();

        $total_pages = ceil($data_query_count->count() / $limit);

        return view('gestor-usuarios', ['data' => $data, 'number_page' => 1, 'count_queries' => $total_pages]);
    }

    // FORMA DE MODIFICACION
    public function forma($id_usuario)
    {

        $generos = Genero::all();
        $formacion = Formacion::all();
        $data = User::where('id', '=', $id_usuario)->first();

        if ($data->type_user == 1) {
            $usuario = Cadian::where('key_user', '=', $data->id)->first();
            $tipos = TipoCadian::all();
        } else {
            $usuario = Cliente::where('key_user', '=', $data->id)->first();
            $tipos = TipoCliente::all();
        }

        return view('gestor-usuariosforma', ['data' => $data, 'usuario' => $usuario, 'generos' => $generos, 'tipos' => $tipos, 'formacion' => $formacion]);
    }

    // METODO DE MODIFICACION
    public function modificar(Request $request)
    {

        if ($request->input('type_user') == 1) {

            $validate = \Validator::make($request->all(), [
                //EJEMPLOS DE SANITIZACIÓN DE DATOS
                'name' => 'required|regex:/^[a-zA-ZÀ-ÖØ-öø-ÿ ]+(\s{0,1}[a-zA-ZÀ-ÖØ-öø-ÿ ])*$/',
                'surname' => 'required|regex:/^[a-zA-ZÀ-ÖØ-öø-ÿ ]+(\s{0,1}[a-zA-ZÀ-ÖØ-öø-ÿ ])*$/',
                'email' => 'required|email|', Rule::unique('users')->ignore($request->input('id')),
                'type_user' => 'required|in:1,2,3',
                'key_tipo_cadian' => 'required|in:1,2,3',
                'key_formacion' => 'required|in:1,2,3,4,5',
                'key_genero' => 'required|in:1,2',
                'direccion' => 'required',
                'telefono' => 'required|min:11|numeric',
                'acerca_de_mi' => 'required',
                'status' => 'required|in:1,2'
            ]);
        } else {
            $validate = \Validator::make($request->all(), [
                //EJEMPLOS DE SANITIZACIÓN DE DATOS
                'name' => 'required|regex:/^[a-zA-ZÀ-ÖØ-öø-ÿ ]+(\s{0,1}[a-zA-ZÀ-ÖØ-öø-ÿ ])*$/',
                'surname' => 'required|regex:/^[a-zA-ZÀ-ÖØ-öø-ÿ ]+(\s{0,1}[a-zA-ZÀ-ÖØ-öø-ÿ ])*$/',
                'email' => 'required|email|', Rule::unique('users')->ignore($request->input('id')),
                'type_user' => 'required|in:1,2,3',
                'key_tipo_cliente' => 'required|in:1,2,3',
                'key_genero' => 'required|in:1,2',
                'direccion' => 'required',
                'telefono' => 'required|min:11|numeric',
                'acerca_de_mi' => 'required',
                'status' => 'required|in:1,2'
            ]);
        }


        if ($validate->fails()) {
            // Hay Error de Validación
            return $validate->errors();
        }

        if ($request['cambiar_imagen'] == 1) {
            // SI LA IMAGEN ES NUEVA, REEMPLAZARLA

            // Validar imagen
            $validate_images = \Validator::make($request->all(), [
                'foto' => 'mimes:jpeg,png',
            ]);

            if ($validate_images->fails()) {
                $data = array(
                    'status' => 'error',
                    'code' => 404,
                    'message' => 'Las imagenes no se han podido subir.',
                    'errors' => $validate_images->errors()
                );

                return response()->json($data, $data['code']);
            }

            //Subir imagen

            $file = $request->file('foto');

            $extension = $file->getClientOriginalExtension();
            //$image_name = time().$file->getClientOriginalName();

            $image_name = time() . '.' . $extension;
            $target_path = public_path('storage/usuarios/');

            if ($file->move($target_path, $image_name)) {

                //ELIMINAMOS FOTO DE PERFIL ANTERIOR
                if ($request->input('type_user') == 1)
                    $anterior_imagen = Cadian::where('key_user', $request['id'])->value('foto');
                else
                    $anterior_imagen = Cliente::where('key_user', $request['id'])->value('foto');

                if ($anterior_imagen != NULL) {
                    $image_path_anterior = public_path() . '/storage/usuarios/' . $anterior_imagen;
                    unlink($image_path_anterior);
                }
            }
        }

        //DATOS TABLA user
        $data = User::find($request->input('id'));

        $data->name = $request->input('name');
        $data->surname = $request->input('surname');
        $data->email = $request->input('email');
        $data->status = $request->input('status');

        if ($request->input('contrasena') != "" || $request->input('contrasena') != "") {
            if (strlen($request->input('contrasena')) >= 8) {
                if ($request->input('contrasena') == $request->input('contrasena_confirm')) {
                    $data->password = hash('sha256', $request->input('contrasena'));
                } else return 'contrasena-no-coincide';
            } else return 'contrasena-menor-8';
        }

        $data->save();


        if ($request->input('type_user') == 1) {
            $update = Cadian::where(['key_user' => $request->input('id')])->update([
                'key_tipo_cadian' => $request->input('key_tipo_cadian'),
                'key_formacion' => $request->input('key_formacion'),
                'nombre' => $request->input('name'),
                'apellidos' => $request->input('surname'),
                'correo' => $request->input('email'),
                'key_genero' => $request->input('key_genero'),
                'direccion' => $request->input('direccion'),
                'telefono' => $request->input('telefono'),
                'acerca_de_mi' => $request->input('acerca_de_mi')
            ]);

            if ($request['cambiar_imagen'] == 1) {
                $update = Cadian::where(['key_user' => $request->input('id')])->update([
                    'foto' => $image_name
                ]);
            }

            // REGISTRO DE MOVIMIENTO
            Movimiento::create(
                [
                    'key_user' => Auth::id(),
                    'seccion' => 'Gestor Usuarios',
                    'opcion' => 'usuario-modificar-cadian',
                    'referencia' => $request->input('id')
                ]
            );
        } else {
            $update = Cliente::where(['key_user' => $request->input('id')])->update([
                'key_tipo_cliente' => $request->input('key_tipo_cliente'),
                'nombre' => $request->input('name'),
                'apellidos' => $request->input('surname'),
                'correo' => $request->input('email'),
                'key_genero' => $request->input('key_genero'),
                'direccion' => $request->input('direccion'),
                'telefono' => $request->input('telefono'),
                'acerca_de_mi' => $request->input('acerca_de_mi')
            ]);

            if ($request['cambiar_imagen'] == 1) {
                $update = Cliente::where(['key_user' => $request->input('id')])->update([
                    'foto' => $image_name
                ]);
            }

            // REGISTRO DE MOVIMIENTO
            Movimiento::create(
                [
                    'key_user' => Auth::id(),
                    'seccion' => 'Gestor Usuarios',
                    'opcion' => 'usuario-modificar-cliente',
                    'referencia' => $request->input('id')
                ]
            );
        }

        return 'success-modificacion-user';
    }


    // METODO PARA LISTAR BUSQUEDA
    public function ajaxBuscar(Request $request)
    {
        $busqueda = $request->input('busqueda');
        $page = $request->input('page');
        if ($request->ajax()) {
            $limit = 5;
            $offset = ($request->page - 1) * $limit;

            $data = User::where('role_user', '!=', 'ADMIN')->where(function ($query) use ($busqueda) {
                $query->where('name', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('surname', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('email', 'LIKE', '%' . $busqueda . '%');
            })->skip($offset)->take($limit)->get();
            $data_query_count = User::where('role_user', '!=', 'ADMIN')->where(function ($query) use ($busqueda) {
                $query->where('name', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('surname', 'LIKE', '%' . $busqueda . '%')
                    ->orWhere('email', 'LIKE', '%' . $busqueda . '%');
            })->get();
            $total_pages = ceil($data_query_count->count() / $limit);
            return view('ajax.gestor-usuarios_data', ['data' => $data, 'number_page' => $page, 'count_queries' => $total_pages])->render();
        }
    }

    // METODO PARA LISTAR BUSQUEDA PAGINADA
    public function ajaxPaginacion(Request $request)
    {
        $busqueda = $request->input('busqueda');

        if ($request->ajax()) {

            $data = User::where('role_user', '!=', 'ADMIN')
                ->when(!empty($busqueda), function ($query) use ($busqueda) {
                    $query->where('name', 'LIKE', '%' . $busqueda . '%')
                        ->orWhere('surname', 'LIKE', '%' . $busqueda . '%')
                        ->orWhere('email', 'LIKE', '%' . $busqueda . '%');
                })
                ->paginate(5);

            return view('ajax.gestor-usuarios_data', compact('data'))->render();
        }
    }

    public function ajaxVerUsuario(Request $request)
    {

        $id_usuario = intval($request->input('id'));

        $data_usuario = User::where(['id' => $id_usuario])->first();

        return view('ajax.gestor_usuarios_token_ajax', compact('data_usuario'));
    }

    public function tokenAcceso(Request $request)
    {

        $id_usuario = $request->input('id');
        $id_admin = Auth::id();

        $token = Str::random(12);

        $startDate = time();
        $fecha_expiracion = date('Y-m-d H:i:s', strtotime('+1 hour', $startDate));


        // REGISTRO DE TOKEN DE ACCESO
        $token_acceso = TokenAcceso::create(
            [
                'key_user' => $id_usuario,
                'key_user_soporte' => $id_admin,
                'token' => $token,
                'fecha_expiracion' => $fecha_expiracion
            ]
        );


        // REGISTRO DE MOVIMIENTO
        Movimiento::create(
            [
                'key_user' => Auth::id(),
                'seccion' => 'Gestor Usuario',
                'opcion' => 'Soporte panel de usuario',
                'referencia' => $id_usuario
            ]
        );

        return $token_acceso;
    }
}
