<?php

namespace App\Http\Controllers;

use App\Http\Requests\UserRequest;
use Illuminate\Support\Facades\Hash;


use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;
use Illuminate\Http\RedirectResponse;
use Carbon\Carbon;

use App\Models\User;
use App\Models\Cliente;
use App\Models\Cadian;
use App\Models\Reserva;
use Illuminate\Support\Facades\Auth;

class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        if (Auth::id()) {
            // RESERVAS
            $reservas_registrados = Reserva::whereBetween('fecha_generada', [Carbon::now()->subDays(30), Carbon::now()])->get();
            $cantidad_reservas = $reservas_registrados->count();

            $reservas_viejas = Reserva::whereBetween('fecha_generada', [Carbon::now()->subDays(61), Carbon::now()->subDays(31)])->get();
            $cantidad_reservas_viejas = $reservas_viejas->count();

            if ($cantidad_reservas == 0) {
                $reservas_nuevas = 0;
                $porcentaje_reservas_nuevas = 0;
            } else {
                $reservas_nuevas = $cantidad_reservas - $cantidad_reservas_viejas;
                $porcentaje_reservas_nuevas = (($cantidad_reservas - $cantidad_reservas_viejas) / $cantidad_reservas) * 100;

                if ($reservas_nuevas <= 0) $reservas_nuevas = 0;
            }


            // CLIENTES
            $clientes_registrados = Cliente::whereBetween('fecha_crea', [Carbon::now()->subDays(7), Carbon::now()])->get();
            $cantidad_clientes = $clientes_registrados->count();

            $clientes_viejos = Cliente::whereBetween('fecha_crea', [Carbon::now()->subDays(14), Carbon::now()->subDays(8)])->get();
            $cantidad_clientes_viejos = $clientes_viejos->count();

            if ($cantidad_clientes == 0) {
                $clientes_nuevos = 0;
                $porcentaje_clientes_nuevos = 0;
            } else {
                $clientes_nuevos = $cantidad_clientes - $cantidad_clientes_viejos;
                $porcentaje_clientes_nuevos = (($cantidad_clientes - $cantidad_clientes_viejos) / $cantidad_clientes) * 100;
            }


            // CADIANS
            $cadians_registrados = Cadian::whereBetween('fecha_crea', [Carbon::now()->subDays(7), Carbon::now()])->get();
            $cantidad_cadians = $cadians_registrados->count();

            $cadians_viejos = Cadian::whereBetween('fecha_crea', [Carbon::now()->subDays(14), Carbon::now()->subDays(8)])->get();
            $cantidad_cadians_viejos = $cadians_viejos->count();

            if ($cantidad_cadians == 0) {
                $cadians_nuevos = 0;
                $porcentaje_cadians_nuevos = 0;
            } else {
                $cadians_nuevos = $cantidad_cadians - $cantidad_cadians_viejos;
                $porcentaje_cadians_nuevos = (($cantidad_cadians - $cantidad_cadians_viejos) / $cantidad_cadians) * 100;
            }


            return view('dashboard', [
                'clientes_nuevos' => $clientes_nuevos,
                'porcentaje_clientes_nuevos' => $porcentaje_clientes_nuevos,
                'cadians_nuevos' => $cadians_nuevos,
                'porcentaje_cadians_nuevos' => $porcentaje_cadians_nuevos,
                'reservas_nuevas' => $reservas_nuevas,
                'porcentaje_reservas_nuevas' => $porcentaje_reservas_nuevas
            ]);
        }
    }
}
