<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Notificacion;
use App\Models\User;
use App\Models\Movimiento;
use Illuminate\Support\Facades\Auth;

class NotificacionController extends Controller
{
    public function index()
    {

        $limit = 10;
        $offset = 0;
        $data = User::latest('id')
            ->skip($offset)->take($limit)->get();
        $data_query_count = User::latest('id')->get();
        $total_pages = ceil($data_query_count->count() / $limit);
        return view('notificaciones', ['data' => $data,  'number_page' => 1, 'count_queries' => $total_pages]);
    }

    public function ajaxPaginacion(Request $request)
    {

        // Validación de datos
        $validate = \Validator::make($request->all(), [
            'busqueda' => 'nullable|regex:/^[a-zA-ZÀ-ÖØ-öø-ÿ ]+(\s{0,1}[a-zA-ZÀ-ÖØ-öø-ÿ ])*$/'
        ]);

        if ($validate->fails()) {
            return;
        }

        $busqueda = $request->input('busqueda');

        if ($request->ajax()) {

            $data = User::where('name', 'LIKE', '%' . $busqueda . '%')
                ->orWhere('surname', 'LIKE', '%' . $busqueda . '%')
                ->paginate(10);

            return view('ajax.notificaciones_ajax', compact('data'))->render();
        }
    }

    public function ajaxBuscar(Request $request)
    {

        // Validación de datos
        $validate = \Validator::make($request->all(), [
            'busqueda' => 'nullable|regex:/^[a-zA-ZÀ-ÖØ-öø-ÿ ]+(\s{0,1}[a-zA-ZÀ-ÖØ-öø-ÿ ])*$/'
        ]);

        if ($validate->fails()) {
            return;
        }

        $busqueda = $request->input('busqueda');
        $page = $request->input('page');
        if ($request->ajax()) {
            $limit = 10;
            $offset = ($request->page - 1) * $limit;
            $data = User::where('name', 'LIKE', '%' . $busqueda . '%')
                ->orWhere('surname', 'LIKE', '%' . $busqueda . '%')
                ->skip($offset)->take($limit)->get();
            $data_query_count = User::where('name', 'LIKE', '%' . $busqueda . '%')
                ->orWhere('surname', 'LIKE', '%' . $busqueda . '%')
                ->get();

            $total_pages = ceil($data_query_count->count() / $limit);
            return view('ajax.notificaciones_ajax', ['data' => $data,  'number_page' => $page, 'count_queries' => $total_pages])->render();
        }
    }

    public function showEstatus($id_estatus)
    {
        $estatus_html = '';

        switch ($id_estatus) {
            case 1:
                $estatus_html = '
                <span class="badge badge-dot mr-4">
                  <i class="bg-success"></i> Activo
                </span>';
                break;
            case 2:
                $estatus_html = '
                <span class="badge badge-dot mr-4">
                  <i class="bg-danger"></i> Baneado
                </span>';
                break;
        }

        return $estatus_html;
    }

    public function enviarNotificacion(Request $request)
    {

        //VALIDAR DATOS DE ENTRADA
        $validate = \Validator::make($request->all(), [
            'mensaje' => 'required|regex:/^[a-zA-ZÀ-ÖØ-öø-ÿ ]+(\s{0,1}[a-zA-ZÀ-ÖØ-öø-ÿ ])*$/',
        ]);

        if ($validate->fails()) {
            return 'Ingresa correctamente el mensaje a enviar.';
        }

        $id_usuario = $request->input('id_usuario');

        if (!is_object(User::find($id_usuario))) {
            return 'La id del usuario es incorrecta.';
        }

        $mensaje = $request->input('mensaje');
        $now = date('Y-m-d H:i:s');

        $insert = Notificacion::insert([
            'key_user' => $id_usuario,
            'texto' => $mensaje,
            'tipo' => 2,
            'fecha' => $now
        ]);

        // REGISTRO DE MOVIMIENTO
        Movimiento::create(
            [
                'key_user' => Auth::id(),
                'seccion' => 'Notificaciones',
                'opcion' => 'envio-notificacion',
                'referencia' => $id_usuario
            ]
        );

        return 'exito';
    }
}
