<?php

namespace App\Http\Controllers;

use Illuminate\Validation\Rule;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

use App\Models\BalancePendiente;
use App\Models\Reserva;
use App\Models\Cliente;
use App\Models\Cadian;
use App\Models\Transaccion;
use App\Models\OpinionCadian;

class ReporteBalancePendienteController extends Controller
{
    public function index()
    {
        $limit = 5;
        $offset = 0;
        // ESTATUS PARA FILTRO
        $estatus = BalancePendiente::select('estatus')->distinct()->get();

        // LISTADO INICIAL DE BALANCES PENDIENTES 
        $balances = BalancePendiente::select(
            'balances_pendientes.*',
            'reservas.fecha_reserva_inicio as fecha_reserva_inicio',
            'reservas.fecha_reserva_final as fecha_reserva_final',
            'reservas.porcentaje_comision as porcentaje_comision',
            'reservas.comentario as comentario',
            'ce_clientes.nombre as nombre_cliente',
            'ce_clientes.apellidos as apellidos_cliente',
            'ce_cadians.nombre as nombre_cadian',
            'ce_cadians.apellidos as apellidos_cadian'
        )
            ->join('reservas', 'reservas.id', '=', 'balances_pendientes.key_referencia')
            ->join('ce_clientes', 'ce_clientes.id_cliente', '=', 'reservas.key_cliente')
            ->join('ce_cadians', 'ce_cadians.id_cadian', '=', 'reservas.key_cadian')
            ->where('balances_pendientes.estatus', 1)
            ->orderBy('reservas.comentario', 'desc')
            ->orderBy('balances_pendientes.fecha', 'asc')
            ->skip($offset)->take($limit)->get();
        $data_query_count = BalancePendiente::select(
            'balances_pendientes.*',
            'reservas.fecha_reserva_inicio as fecha_reserva_inicio',
            'reservas.fecha_reserva_final as fecha_reserva_final',
            'reservas.porcentaje_comision as porcentaje_comision',
            'reservas.comentario as comentario',
            'ce_clientes.nombre as nombre_cliente',
            'ce_clientes.apellidos as apellidos_cliente',
            'ce_cadians.nombre as nombre_cadian',
            'ce_cadians.apellidos as apellidos_cadian'
        )
            ->join('reservas', 'reservas.id', '=', 'balances_pendientes.key_referencia')
            ->join('ce_clientes', 'ce_clientes.id_cliente', '=', 'reservas.key_cliente')
            ->join('ce_cadians', 'ce_cadians.id_cadian', '=', 'reservas.key_cadian')
            ->where('balances_pendientes.estatus', 1)
            ->orderBy('reservas.comentario', 'desc')
            ->orderBy('balances_pendientes.fecha', 'asc')->get();
        $number_page = 1;
        $count_queries  = ceil($data_query_count->count() / $limit);
        return view('reporte-balances-pendientes', compact('balances', 'estatus', 'number_page', 'count_queries'));
    }


    public function ajaxBuscar(Request $request)
    {
        $busqueda_selected = $request->input('busqueda_filtro');
        $estatus_selected = $request->input('estatus_filtro');
        $page = $request->input('page');
        if ($request->ajax()) {
            $limit = 5;
            $offset = ($page - 1) * $limit;
            // LISTADO DE transacciones FILTRADOS

            $balances = BalancePendiente::select(
                'balances_pendientes.*',
                'reservas.fecha_reserva_inicio as fecha_reserva_inicio',
                'reservas.fecha_reserva_final as fecha_reserva_final',
                'reservas.porcentaje_comision as porcentaje_comision',
                'reservas.comentario as comentario',
                'ce_clientes.nombre as nombre_cliente',
                'ce_clientes.apellidos as apellidos_cliente',
                'ce_cadians.nombre as nombre_cadian',
                'ce_cadians.apellidos as apellidos_cadian'
            )
                ->join('reservas', 'reservas.id', '=', 'balances_pendientes.key_referencia')
                ->join('ce_clientes', 'ce_clientes.id_cliente', '=', 'reservas.key_cliente')
                ->join('ce_cadians', 'ce_cadians.id_cadian', '=', 'reservas.key_cadian')

                ->where(function ($query) use ($busqueda_selected, $estatus_selected, $request) {

                    if ($request->input('busqueda_filtro') != "") {
                        $query->where('balances_pendientes.key_referencia', '=', $busqueda_selected);
                    }
                    if ($request->input('estatus_filtro') != "") {
                        $query->where('balances_pendientes.estatus', '=', $estatus_selected);
                    }
                })
                ->orderBy('reservas.comentario', 'desc')
                ->orderBy('balances_pendientes.fecha', 'asc')
                ->skip($offset)->take($limit)->get();
            $data_query_count  =  BalancePendiente::select(
                'balances_pendientes.*',
                'reservas.fecha_reserva_inicio as fecha_reserva_inicio',
                'reservas.fecha_reserva_final as fecha_reserva_final',
                'reservas.porcentaje_comision as porcentaje_comision',
                'reservas.comentario as comentario',
                'ce_clientes.nombre as nombre_cliente',
                'ce_clientes.apellidos as apellidos_cliente',
                'ce_cadians.nombre as nombre_cadian',
                'ce_cadians.apellidos as apellidos_cadian'
            )
                ->join('reservas', 'reservas.id', '=', 'balances_pendientes.key_referencia')
                ->join('ce_clientes', 'ce_clientes.id_cliente', '=', 'reservas.key_cliente')
                ->join('ce_cadians', 'ce_cadians.id_cadian', '=', 'reservas.key_cadian')

                ->where(function ($query) use ($busqueda_selected, $estatus_selected, $request) {

                    if ($request->input('busqueda_filtro') != "") {
                        $query->where('balances_pendientes.key_referencia', '=', $busqueda_selected);
                    }
                    if ($request->input('estatus_filtro') != "") {
                        $query->where('balances_pendientes.estatus', '=', $estatus_selected);
                    }
                })
                ->orderBy('reservas.comentario', 'desc')
                ->orderBy('balances_pendientes.fecha', 'asc')->get();
            $count_queries = ceil($data_query_count->count() / $limit);
            $number_page = $request->input('page');
            return view('ajax.reporte-balances-pendientes_data', compact('balances', 'number_page', 'count_queries'))->render();
        }
    }


    public function ajaxPaginacion(Request $request)
    {
        $busqueda_selected = $request->input('busqueda_filtro');
        $estatus_selected = $request->input('estatus_filtro');

        if ($request->ajax()) {

            // LISTADO DE transacciones FILTRADOS

            $balances = BalancePendiente::select(
                'balances_pendientes.*',
                'reservas.fecha_reserva_inicio as fecha_reserva_inicio',
                'reservas.fecha_reserva_final as fecha_reserva_final',
                'reservas.porcentaje_comision as porcentaje_comision',
                'reservas.comentario as comentario',
                'ce_clientes.nombre as nombre_cliente',
                'ce_clientes.apellidos as apellidos_cliente',
                'ce_cadians.nombre as nombre_cadian',
                'ce_cadians.apellidos as apellidos_cadian'
            )
                ->join('reservas', 'reservas.id', '=', 'balances_pendientes.key_referencia')
                ->join('ce_clientes', 'ce_clientes.id_cliente', '=', 'reservas.key_cliente')
                ->join('ce_cadians', 'ce_cadians.id_cadian', '=', 'reservas.key_cadian')
                ->when(!empty($busqueda_selected), function ($query) use ($busqueda_selected) {
                    $query->where('balances_pendientes.key_referencia', '=', $busqueda_selected);
                })
                ->when(!empty($estatus_selected), function ($query) use ($estatus_selected) {
                    $query->where('balances_pendientes.estatus', '=', $estatus_selected);
                })
                ->orderBy('reservas.comentario', 'desc')
                ->orderBy('balances_pendientes.fecha', 'asc')
                ->paginate(5);

            return view('ajax.reporte-balances-pendientes_data', compact('balances'))->render();
        }
    }


    public function ajaxVerDatosReserva(Request $request)
    {


        $id_reserva = intval($request->input('id_reserva'));
        $accion = $request->input('accion');

        // LISTADO INICIAL DE BALANCES PENDIENTES
        $balance_pendiente = BalancePendiente::where('key_referencia', '=', $id_reserva)->first()->toArray();

        // LISTADO INICIAL DE BALANCES PENDIENTES
        $reserva = Reserva::select(
            'reservas.*',
            'ce_clientes.nombre as nombre_cliente',
            'ce_clientes.apellidos as apellidos_cliente',
            'ce_clientes.correo as correo_cliente',
            'ce_cadians.nombre as nombre_cadian',
            'ce_cadians.apellidos as apellidos_cadian',
            'ce_cadians.correo as correo_cadian'
        )
            ->join('ce_clientes', 'ce_clientes.id_cliente', '=', 'reservas.key_cliente')
            ->join('ce_cadians', 'ce_cadians.id_cadian', '=', 'reservas.key_cadian')
            ->where('id', '=', $id_reserva)
            ->first()->toArray();

        //CLIENTE
        $cliente = Cliente::where('id_cliente', '=', $reserva['key_cliente'])->first();

        //COMENTARIOS
        if ($reserva['comentario'] == 1) {
            $opinion = OpinionCadian::where('token_reserva', '=', $reserva['token_identificacion'])->first()->toArray();
        } else {
            $opinion = "";
        }

        // TRANSACCION
        $id_cargo = 56; //Pago de la reserva
        $transaccion = Transaccion::select('ce_transacciones.*')
            ->where('key_id_cargo', '=', $id_cargo)
            ->where('key_user', '=', $cliente->key_user)
            ->where('token_referencia', '=', $reserva['token_identificacion'])
            ->first()->toArray();

        return view('ajax.reporte-balances-pendientes-liberar_ajax', compact('balance_pendiente', 'reserva', 'transaccion', 'accion', 'opinion'));
    }



    public function liberarBalancePendiente(Request $request)
    {


        $id_balancep = intval($request->input('id_balancep'));
        $key_referencia = intval($request->input('key_referencia'));
        $id_reserva = intval($request->input('id_reserva'));

        /////////////////////////

        // LISTADO INICIAL DE BALANCES PENDIENTES
        //$balance_pendiente = BalancePendiente::where('key_referencia', '=', $id_reserva)->first()->toArray();

        // LISTADO INICIAL DE BALANCES PENDIENTES
        $reserva = Reserva::select(
            'reservas.*',
            'ce_clientes.nombre as nombre_cliente',
            'ce_clientes.apellidos as apellidos_cliente',
            'ce_clientes.correo as correo_cliente',
            'ce_cadians.nombre as nombre_cadian',
            'ce_cadians.apellidos as apellidos_cadian',
            'ce_cadians.correo as correo_cadian'
        )
            ->join('ce_clientes', 'ce_clientes.id_cliente', '=', 'reservas.key_cliente')
            ->join('ce_cadians', 'ce_cadians.id_cadian', '=', 'reservas.key_cadian')
            ->where('id', '=', $id_reserva)
            ->first()->toArray();

        //CLIENTE
        $cliente = Cliente::where('id_cliente', '=', $reserva['key_cliente'])->first();
        //CLIENTE
        $cadian = Cadian::where('id_cadian', '=', $reserva['key_cadian'])->first();


        // TRANSACCION
        $id_cargo = 56; //Pago de la reserva
        $transaccion = Transaccion::select('ce_transacciones.*')
            ->where('key_id_cargo', '=', $id_cargo)
            ->where('key_user', '=', $cliente->key_user)
            ->where('token_referencia', '=', $reserva['token_identificacion'])
            ->first()->toArray();

        $monto_a_pagar = $reserva['monto_total'] / (1 + ($reserva['porcentaje_comision'] / 100));
        $comision_a_pagar = $reserva['monto_total'] - $monto_a_pagar;

        $now = date('d-m-Y H:i:s');
        ////////////////


        $update2 = DB::table('balances_pendientes')
            ->where(['id' => $id_balancep, 'key_referencia' => $key_referencia])
            ->update(['estatus' => 2]);

        $update3 = DB::table('balances')->where('key_user', '=', $cadian['key_user'])
            ->update([
                'balance' => DB::raw('balance +' . $monto_a_pagar)
            ]);


        $insert2 = DB::table('logs_balances')
            ->insert([
                'key_user' => $cadian['key_user'],
                'tipo' => 'Pago',
                'monto' => $monto_a_pagar,
                'fecha' => date('d-m-Y H:i:s')
            ]);

        $id_cargo = 57; // id de la liberación del pago

        //NUEVO REGISTRO EN EL LOG DE TRANSACCIONES
        $transacc =  DB::table('ce_transacciones')->insert([
            'key_id_cargo' => $id_cargo,
            'key_user' => $cadian['key_user'],
            'token_referencia' => $reserva['token_identificacion'],
            'tipo_transaccion' => 'LIBERACION-RESERVA',
            'monto' => $monto_a_pagar,
            'fecha' => date('d-m-Y H:i:s')
        ]);

        $id_cargo = 58; // id de la liberación del pago

        //NUEVO REGISTRO EN EL LOG DE TRANSACCIONES
        $transacc =  DB::table('ce_transacciones')->insert([
            'key_id_cargo' => $id_cargo,
            'key_user' => 16,
            'token_referencia' => $reserva['token_identificacion'],
            'tipo_transaccion' => 'COMISION-RESERVA',
            'monto' => $comision_a_pagar,
            'fecha' => date('d-m-Y H:i:s')
        ]);

        $insert_notificacion_reserva = DB::table('notificaciones')
            ->insert([
                'key_user' => $cadian['key_user'],
                'texto' => 'Se ha liberado el pago por una nueva reserva. Click aquí para mas detalles',
                'tipo' => 11,
                'id_referencia' => $reserva['token_identificacion'],
                'fecha' => $now
            ]);

        $data = array(
            'status' => 'success',
            'code' => 200,
            'statusText' => 'exito'
        );

        return response()->json($data, $data['code']);
    }

    public function cancelarBalancePendiente(Request $request)
    {


        $id_balancep = intval($request->input('id_balancep'));
        $key_referencia = intval($request->input('key_referencia'));
        $id_reserva = intval($request->input('id_reserva'));

        /////////////////////////

        // LISTADO INICIAL DE BALANCES PENDIENTES
        //$balance_pendiente = BalancePendiente::where('key_referencia', '=', $id_reserva)->first()->toArray();

        // LISTADO INICIAL DE BALANCES PENDIENTES
        $reserva = Reserva::select(
            'reservas.*',
            'ce_clientes.nombre as nombre_cliente',
            'ce_clientes.apellidos as apellidos_cliente',
            'ce_clientes.correo as correo_cliente',
            'ce_cadians.nombre as nombre_cadian',
            'ce_cadians.apellidos as apellidos_cadian',
            'ce_cadians.correo as correo_cadian'
        )
            ->join('ce_clientes', 'ce_clientes.id_cliente', '=', 'reservas.key_cliente')
            ->join('ce_cadians', 'ce_cadians.id_cadian', '=', 'reservas.key_cadian')
            ->where('id', '=', $id_reserva)
            ->first()->toArray();

        //CLIENTE
        $cliente = Cliente::where('id_cliente', '=', $reserva['key_cliente'])->first();
        //CLIENTE
        $cadian = Cadian::where('id_cadian', '=', $reserva['key_cadian'])->first();


        // TRANSACCION
        $id_cargo = 56; //Pago de la reserva
        $transaccion = Transaccion::select('ce_transacciones.*')
            ->where('key_id_cargo', '=', $id_cargo)
            ->where('key_user', '=', $cliente->key_user)
            ->where('token_referencia', '=', $reserva['token_identificacion'])
            ->first()->toArray();


        $now = date('d-m-Y H:i:s');
        ////////////////


        $update2 = DB::table('balances_pendientes')
            ->where(['id' => $id_balancep, 'key_referencia' => $key_referencia])
            ->update(['estatus' => 3]);

        //REGRESAR DINERO AL CLIENTE POR CANCELACION DE BALANCE PENDIENTE
        ////////      

        $update3 = DB::table('balances')->where('key_user', '=', $cliente->key_user)
            ->update([
                'balance' => DB::raw('balance +' . $reserva['monto_total'])
            ]);


        $insert2 = DB::table('logs_balances')
            ->insert([
                'key_user' => $cliente['key_user'],
                'tipo' => 'Devolucion',
                'monto' => $reserva['monto_total'],
                'fecha' => date('d-m-Y H:i:s')
            ]);

        $id_cargo = 50; // id de la liberación del pago

        //NUEVO REGISTRO EN EL LOG DE TRANSACCIONES
        $transacc =  DB::table('ce_transacciones')->insert([
            'key_id_cargo' => $id_cargo,
            'key_user' => $cliente['key_user'],
            'token_referencia' => $reserva['token_identificacion'],
            'tipo_transaccion' => 'DEVOLUCION-RESERVA',
            'monto' => $reserva['monto_total'],
            'fecha' => date('d-m-Y H:i:s')
        ]);

        // CANCELAR RESERVACION
        $update = DB::table('reservas')
            ->where([
                'token_identificacion' => $reserva['token_identificacion'],
            ])
            ->update(['estatus_reserva' => 6]);

        //NOTIFICACION

        $insert_notificacion_reserva = DB::table('notificaciones')
            ->insert([
                'key_user' => $cliente['key_user'],
                'texto' => 'Se generó una devolución por la cancelación de balance pendiente (pago de reserva). Click aquí para mas detalles',
                'tipo' => 11,
                'id_referencia' => $reserva['token_identificacion'],
                'fecha' => $now
            ]);

        $data = array(
            'status' => 'success',
            'code' => 200,
            'statusText' => 'exito'
        );

        return response()->json($data, $data['code']);
    }
}
