<?php

namespace App\Http\Controllers;

use Illuminate\Validation\Rule;
use Illuminate\Http\Request;
use App\Models\Movimiento;

class ReporteMovimientoController extends Controller
{

    public function index()
    {
        $limit = 5;
        $offset = 0;

        // CATEGORIAS PARA FILTRO
        $secciones = Movimiento::select('seccion')->distinct()->get();

        // LISTADO INICIAL DE MOVIMIENTOS
        $movimientos = Movimiento::select('admin_movimientos.*', 'users.name as name', 'users.surname as surname')
            ->join('users', 'users.id', '=', 'admin_movimientos.key_user')
            ->skip($offset)->take($limit)->get();

        $data_query_count = Movimiento::select('admin_movimientos.*', 'users.name as name', 'users.surname as surname')
            ->join('users', 'users.id', '=', 'admin_movimientos.key_user')->get();

        $number_page = 1;
        $count_queries  = ceil($data_query_count->count() / $limit);
        return view('reporte-movimientos', compact('movimientos', 'secciones', 'number_page', 'count_queries'));
    }


    public function ajaxBuscar(Request $request)
    {
        $seccion_selected = $request->input('seccion_filtro');
        $fecha_inicio_selected = $request->input('fecha_inicio_filtro') . " 00:00:00";
        $fecha_termino_selected = $request->input('fecha_termino_filtro') . " 23:59:59";
        $page = $request->input('page');
        if ($request->ajax()) {
            $limit = 5;
            $offset = ($page - 1) * $limit;
            // LISTADO DE MOVIMIENTOS FILTRADOS

            if ($seccion_selected != "") {
                $movimientos = Movimiento::select('admin_movimientos.*', 'users.name as name', 'users.surname as surname')
                    ->join('users', 'users.id', '=', 'admin_movimientos.key_user')
                    ->where('admin_movimientos.seccion', '=', $seccion_selected)
                    ->where(function ($query) use ($fecha_inicio_selected, $fecha_termino_selected, $request) {

                        if ($request->input('fecha_inicio_filtro') != $request->input('fecha_termino_filtro')) {
                            $query->whereBetween('ce_transacciones.fecha', [$fecha_inicio_selected, $fecha_termino_selected]);
                        }
                    })->skip($offset)->take($limit)->get();
                $data_query_count  = Movimiento::select('admin_movimientos.*', 'users.name as name', 'users.surname as surname')
                    ->join('users', 'users.id', '=', 'admin_movimientos.key_user')
                    ->where('admin_movimientos.seccion', '=', $seccion_selected)
                    ->where(function ($query) use ($fecha_inicio_selected, $fecha_termino_selected, $request) {

                        if ($request->input('fecha_inicio_filtro') != $request->input('fecha_termino_filtro')) {
                            $query->whereBetween('ce_transacciones.fecha', [$fecha_inicio_selected, $fecha_termino_selected]);
                        }
                    })->get();
            } else {
                $movimientos = Movimiento::select('admin_movimientos.*', 'users.name as name', 'users.surname as surname')
                    ->join('users', 'users.id', '=', 'admin_movimientos.key_user')
                    ->where(function ($query) use ($fecha_inicio_selected, $fecha_termino_selected, $request) {

                        if ($request->input('fecha_inicio_filtro') != $request->input('fecha_termino_filtro')) {
                            $query->whereBetween('ce_transacciones.fecha', [$fecha_inicio_selected, $fecha_termino_selected]);
                        }
                    })->skip($offset)->take($limit)->get();
                $data_query_count  = Movimiento::select('admin_movimientos.*', 'users.name as name', 'users.surname as surname')
                    ->join('users', 'users.id', '=', 'admin_movimientos.key_user')
                    ->where(function ($query) use ($fecha_inicio_selected, $fecha_termino_selected, $request) {

                        if ($request->input('fecha_inicio_filtro') != $request->input('fecha_termino_filtro')) {
                            $query->whereBetween('ce_transacciones.fecha', [$fecha_inicio_selected, $fecha_termino_selected]);
                        }
                    })->get();
            }
            $number_page = $page;
            $count_queries  = ceil($data_query_count->count() / $limit);

            return view('ajax.reporte-movimientos_data', compact('movimientos', 'number_page', 'count_queries'))->render();
        }
    }



    //public function ajaxPaginacion($page, $seccion, $fecha_inicio, $fecha_termino)
    public function ajaxPaginacion(Request $request)
    {
        /*$seccion_selected = $seccion;
        $fecha_inicio_selected = $fecha_inicio;
        $fecha_termino_selected = $fecha_termino;*/


        $seccion_selected = $request->input('seccion_filtro');
        $fecha_inicio_selected = $request->input('fecha_inicio_filtro') . " 00:00:00";
        $fecha_termino_selected = $request->input('fecha_termino_filtro') . " 23:59:59";


        if ($request->ajax()) {

            // LISTADO DE MOVIMIENTOS FILTRADOS

            $movimientos = Movimiento::select('admin_movimientos.*', 'users.name as name', 'users.surname as surname')
                ->join('users', 'users.id', '=', 'admin_movimientos.key_user')
                ->when(!empty($seccion_selected), function ($query) use ($seccion_selected) {
                    $query->where('admin_movimientos.seccion', '=', $seccion_selected);
                })
                ->whereBetween('admin_movimientos.fecha_movto', [$fecha_inicio_selected, $fecha_termino_selected])
                ->paginate(5);
        }

        return view('ajax.reporte-movimientos_data', compact('movimientos'))->render();
    }
}
