<?php

namespace App\Http\Controllers;

use Illuminate\Validation\Rule;
use Illuminate\Http\Request;
use App\Models\Penalizacion;
use App\Models\TipoPenalizacion;

class ReportePenalizacionController extends Controller
{
    public function index()
    {
        $limit = 5;
        $offset = 0;
        // TIPO PARA FILTRO
        $tipos = TipoPenalizacion::all();

        // LISTADO INICIAL DE PENALIZACIONES
        $penalizaciones = Penalizacion::select(
            'ce_penalizaciones.*',
            'ci_tipos_penalizaciones.nombre as tipo',
            'ce_multas.monto as monto',
            'users.name as name',
            'users.surname as surname',
            'users.role_user as role_user'
        )
            ->join('ci_tipos_penalizaciones', 'ci_tipos_penalizaciones.id_tipo_penalizacion', '=', 'ce_penalizaciones.key_tipo_penalizacion')
            ->join('ce_multas', 'ce_multas.id', '=', 'ce_penalizaciones.key_multa')
            ->join('users', 'users.id', '=', 'ce_penalizaciones.key_user')
            ->skip($offset)->take($limit)->get();

        $data_query_count =
            Penalizacion::select(
                'ce_penalizaciones.*',
                'ci_tipos_penalizaciones.nombre as tipo',
                'ce_multas.monto as monto',
                'users.name as name',
                'users.surname as surname',
                'users.role_user as role_user'
            )
            ->join('ci_tipos_penalizaciones', 'ci_tipos_penalizaciones.id_tipo_penalizacion', '=', 'ce_penalizaciones.key_tipo_penalizacion')
            ->join('ce_multas', 'ce_multas.id', '=', 'ce_penalizaciones.key_multa')
            ->join('users', 'users.id', '=', 'ce_penalizaciones.key_user')->get();
        $number_page = 1;
        $count_queries  = ceil($data_query_count->count() / $limit);
        return view('reporte-penalizaciones', compact('penalizaciones', 'tipos', 'number_page', 'count_queries'));
    }


    public function ajaxBuscar(Request $request)
    {
        $tipo_selected = $request->input('tipo_filtro');
        $role_selected = $request->input('role_user_filtro');
        $fecha_inicio_selected = $request->input('fecha_inicio_filtro') . " 00:00:00";
        $fecha_termino_selected = $request->input('fecha_termino_filtro') . " 23:59:59";
        $page = $request->input('page');

        if ($request->ajax()) {

            $limit = 5;
            $offset = ($page - 1) * $limit;
            $penalizaciones = Penalizacion::select(
                'ce_penalizaciones.*',
                'ci_tipos_penalizaciones.nombre as tipo',
                'ce_multas.monto as monto',
                'users.name as name',
                'users.surname as surname',
                'users.role_user as role_user'
            )
                ->join('ci_tipos_penalizaciones', 'ci_tipos_penalizaciones.id_tipo_penalizacion', '=', 'ce_penalizaciones.key_tipo_penalizacion')
                ->join('ce_multas', 'ce_multas.id', '=', 'ce_penalizaciones.key_multa')
                ->join('users', 'users.id', '=', 'ce_penalizaciones.key_user')
                ->where(function ($query) use ($fecha_inicio_selected, $fecha_termino_selected, $tipo_selected, $role_selected, $request) {
                    if (!empty($request->input('fecha_inicio_filtro')) && !empty($request->input('fecha_termino_filtro'))) {
                        if ($request->input('fecha_inicio_filtro') != $request->input('fecha_termino_filtro')) {
                            $query->whereBetween('ce_multas.fecha', [$fecha_inicio_selected, $fecha_termino_selected]);
                        }
                    }
                    if ($request->input('tipo_filtro') != "") {
                        $query->where('ce_penalizaciones.key_tipo_penalizacion', '=', $tipo_selected);
                    }
                    if ($request->input('role_user_filtro') != "") {
                        $query->where('users.role_user', '=', $role_selected);
                    }
                })->skip($offset)->take($limit)->get();

            $data_query_count  =  Penalizacion::select(
                'ce_penalizaciones.*',
                'ci_tipos_penalizaciones.nombre as tipo',
                'ce_multas.monto as monto',
                'users.name as name',
                'users.surname as surname',
                'users.role_user as role_user'
            )
                ->join('ci_tipos_penalizaciones', 'ci_tipos_penalizaciones.id_tipo_penalizacion', '=', 'ce_penalizaciones.key_tipo_penalizacion')
                ->join('ce_multas', 'ce_multas.id', '=', 'ce_penalizaciones.key_multa')
                ->join('users', 'users.id', '=', 'ce_penalizaciones.key_user')
                ->where(function ($query) use ($fecha_inicio_selected, $fecha_termino_selected, $tipo_selected, $role_selected, $request) {
                    if (!empty($request->input('fecha_inicio_filtro')) && !empty($request->input('fecha_termino_filtro'))) {
                        if ($request->input('fecha_inicio_filtro') != $request->input('fecha_termino_filtro')) {
                            $query->whereBetween('ce_multas.fecha', [$fecha_inicio_selected, $fecha_termino_selected]);
                        }
                    }
                    if ($request->input('tipo_filtro') != "") {
                        $query->where('ce_penalizaciones.key_tipo_penalizacion', '=', $tipo_selected);
                    }
                    if ($request->input('role_user_filtro') != "") {
                        $query->where('users.role_user', '=', $role_selected);
                    }
                })->get();
            $count_queries = ceil($data_query_count->count() / $limit);
            $number_page = $request->input('page');
        }

        return view('ajax.reporte-penalizaciones_data', compact('penalizaciones', 'number_page', 'count_queries'))->render();
    }



    public function ajaxPaginacion(Request $request)
    {
        $tipo_selected = $request->input('tipo_filtro');
        $role_selected = $request->input('role_user_filtro');
        $fecha_inicio_selected = $request->input('fecha_inicio_filtro') . " 00:00:00";
        $fecha_termino_selected = $request->input('fecha_termino_filtro') . " 23:59:59";

        if ($request->ajax()) {

            $penalizaciones = Penalizacion::select(
                'ce_penalizaciones.*',
                'ci_tipos_penalizaciones.nombre as tipo',
                'ce_multas.monto as monto',
                'users.name as name',
                'users.surname as surname',
                'users.role_user as role_user'
            )
                ->join('ci_tipos_penalizaciones', 'ci_tipos_penalizaciones.id_tipo_penalizacion', '=', 'ce_penalizaciones.key_tipo_penalizacion')
                ->join('ce_multas', 'ce_multas.id', '=', 'ce_penalizaciones.key_multa')
                ->join('users', 'users.id', '=', 'ce_penalizaciones.key_user')
                ->when(!empty($request->input('tipo_filtro')), function ($query) use ($tipo_selected) {
                    $query->where('ce_penalizaciones.key_tipo_penalizacion', '=', $tipo_selected);
                })
                ->when(!empty($request->input('role_user_filtro')), function ($query) use ($role_selected) {
                    $query->where('users.role_user', '=', $role_selected);
                })
                ->when((!empty($request->input('fecha_inicio_filtro')) && !empty($request->input('fecha_termino_filtro'))), function ($query) use ($fecha_inicio_selected, $fecha_termino_selected) {
                    $query->whereBetween('ce_penalizaciones.fecha', [$fecha_inicio_selected, $fecha_termino_selected]);
                })
                ->paginate(5);
        }

        return view('ajax.reporte-penalizaciones_data', compact('penalizaciones'))->render();
    }
}
