<?php

namespace App\Http\Controllers;


use Illuminate\Validation\Rule;
use Illuminate\Http\Request;
use App\Models\SolicitudHistorico;

class ReporteSolicitudCadianController extends Controller
{
    public function index()
    {
        $limit = 5;
        $offset = 0;
        // CATEGORIAS PARA FILTRO
        $estatus = ['Rechazadas', 'Aceptadas'];

        // LISTADO INICIAL DE SOLICITUDES
        $solicitudes = SolicitudHistorico::select('ce_solicitudes_historico.*', 'ce_cadians.nombre as nombre', 'ce_cadians.apellidos as apellidos', 'users.name as name', 'users.surname as surname')
            ->join('ce_cadians', 'ce_cadians.id_cadian', '=', 'ce_solicitudes_historico.key_cadian')
            ->join('users', 'users.id', '=', 'ce_solicitudes_historico.key_user_admin')
            ->skip($offset)->take($limit)->get();
        $data_query_count = SolicitudHistorico::select('ce_solicitudes_historico.*', 'ce_cadians.nombre as nombre', 'ce_cadians.apellidos as apellidos', 'users.name as name', 'users.surname as surname')
            ->join('ce_cadians', 'ce_cadians.id_cadian', '=', 'ce_solicitudes_historico.key_cadian')
            ->join('users', 'users.id', '=', 'ce_solicitudes_historico.key_user_admin')
            ->get();
        $number_page = 1;
        $count_queries  = ceil($data_query_count->count() / $limit);
        return view('reporte-solicitudes-cadian', compact('solicitudes', 'estatus', 'number_page', 'count_queries'));
    }


    public function ajaxBuscar(Request $request)
    {
        $estatus_selected = $request->input('estatus_filtro');
        $fecha_inicio_selected = $request->input('fecha_inicio_filtro') . " 00:00:00";
        $fecha_termino_selected = $request->input('fecha_termino_filtro') . " 23:59:59";
        $page = $request->input('page');
        if ($request->ajax()) {
            $limit = 5;
            $offset = ($page - 1) * $limit;

            // LISTADO DE SOLICITUDES FILTRADOS

            $solicitudes = SolicitudHistorico::select('ce_solicitudes_historico.*', 'ce_cadians.nombre as nombre', 'ce_cadians.apellidos as apellidos', 'users.name as name', 'users.surname as surname')
                ->join('ce_cadians', 'ce_cadians.id_cadian', '=', 'ce_solicitudes_historico.key_cadian')
                ->join('users', 'users.id', '=', 'ce_solicitudes_historico.key_user_admin')
                ->where(function ($query) use ($fecha_inicio_selected, $fecha_termino_selected, $estatus_selected, $request) {
                    if ($request->input('fecha_inicio_filtro')  != $request->input('fecha_termino_filtro')) {
                        $query->whereBetween('ce_solicitudes_historico.fecha_movimiento', [$fecha_inicio_selected, $fecha_termino_selected]);
                    }
                    if ($estatus_selected != "") {
                        $query->where('ce_solicitudes_historico.estatus', '=', $estatus_selected);
                    }
                })->skip($offset)->take($limit)->get();

            $data_query_count = SolicitudHistorico::select('ce_solicitudes_historico.*', 'ce_cadians.nombre as nombre', 'ce_cadians.apellidos as apellidos', 'users.name as name', 'users.surname as surname')
                ->join('ce_cadians', 'ce_cadians.id_cadian', '=', 'ce_solicitudes_historico.key_cadian')
                ->join('users', 'users.id', '=', 'ce_solicitudes_historico.key_user_admin')
                ->where(function ($query) use ($fecha_inicio_selected, $fecha_termino_selected, $estatus_selected, $request) {
                    if ($request->input('fecha_inicio_filtro')  != $request->input('fecha_termino_filtro')) {
                        $query->whereBetween('ce_solicitudes_historico.fecha_movimiento', [$fecha_inicio_selected, $fecha_termino_selected]);
                    }
                    if ($estatus_selected != "") {
                        $query->where('ce_solicitudes_historico.estatus', '=', $estatus_selected);
                    }
                })->get();


            $count_queries = ceil($data_query_count->count() / $limit);
            $number_page = $request->input('page');



            return view('ajax.reporte-solicitudes-cadian_data', compact('solicitudes', 'number_page', 'count_queries'))->render();
        }
    }


    public function ajaxPaginacion(Request $request)
    {
        $estatus_selected = $request->input('estatus_filtro');
        $fecha_inicio_selected = $request->input('fecha_inicio_filtro') . " 00:00:00";
        $fecha_termino_selected = $request->input('fecha_termino_filtro') . " 23:59:59";

        if ($request->ajax()) {

            // LISTADO DE SOLICITUDES FILTRADOS

            $solicitudes = SolicitudHistorico::select('ce_solicitudes_historico.*', 'ce_cadians.nombre as nombre', 'ce_cadians.apellidos as apellidos', 'users.name as name', 'users.surname as surname')
                ->join('ce_cadians', 'ce_cadians.id_cadian', '=', 'ce_solicitudes_historico.key_cadian')
                ->join('users', 'users.id', '=', 'ce_solicitudes_historico.key_user_admin')
                ->when(!empty($estatus_selected), function ($query) use ($estatus_selected) {
                    $query->where('ce_solicitudes_historico.estatus', '=', $estatus_selected);
                })
                ->whereBetween('ce_solicitudes_historico.fecha_movimiento', [$fecha_inicio_selected, $fecha_termino_selected])
                ->paginate(5);
        }

        return view('ajax.reporte-solicitudes-cadian_data', compact('solicitudes'))->render();
    }
}
